from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class GR(PredefinedNamespace):
    """The GoodRelations Vocabulary for Semantic Web-based E-Commerce"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://www.heppnetz.de/ontologies/goodrelations/v1.owl

    _nsBaseIri = "http://purl.org/goodrelations/v1#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = (
        "Labor-BringIn",
        "N-Ary-Relations",
        "PartsAndLabor-BringIn",
        "PartsAndLabor-PickUp",
        "hasEAN_UCC-13",
        "hasGTIN-14",
        "hasGTIN-8",
    )

    ActualProductOrServiceInstance: NamedNode
    """DEPRECATED - This class is superseded by gr:Individual. Replace all occurrences of gr:ActualProductOrServiceInstance by gr:Individual, if possible."""
    AmericanExpress: NamedNode
    """Payment by credit or debit cards issued by the American Express network."""
    Brand: NamedNode
    """A brand is the identity of a specific product, service, or business. Use foaf:logo for attaching a brand logo and gr:name or rdfs:label for attaching the brand name.	

(Source: Wikipedia, the free encyclopedia, see http://en.wikipedia.org/wiki/Brand)"""
    Business: NamedNode
    """The gr:BusinessEntityType representing such agents that are themselves offering commercial services or products on the market. Usually, businesses are characterized by the fact that they are officially registered with the public administration and strive for profits by their activities."""
    BusinessEntity: NamedNode
    """An instance of this class represents the legal agent making (or seeking) a particular offering. This can be a legal body or a person. A business entity has at least a primary mailing address and contact details. For this, typical address standards (vCard) and location data (geo, WGS84) can be attached. Note that the location of the business entity is not necessarily the location from which the product or service is being available (e.g. the branch or store). Use gr:Location for stores and branches.
		
Example: Siemens Austria AG, Volkswagen Ltd., Peter Miller's Cell phone Shop LLC

Compatibility with schema.org: This class is equivalent to the union of http://schema.org/Person and http://schema.org/Organization.		
"""
    BusinessEntityType: NamedNode
    """A business entity type is a conceptual entity representing the legal form, the size, the main line of business, the position in the value chain, or any combination thereof, of a gr:BusinessEntity. From the ontological point of view, business entity types are mostly roles that a business entity has in the market. Business entity types are important for specifying eligible customers, since a gr:Offering is often valid only for business entities of a certain size, legal structure, or role in the value chain. 

Examples: Consumers, Retailers, Wholesalers, or Public Institutions"""
    BusinessFunction: NamedNode
    """The business function specifies the type of activity or access (i.e., the bundle of rights) offered by the gr:BusinessEntity on the gr:ProductOrService through the gr:Offering. Typical are sell, rental or lease, maintenance or repair, manufacture / produce, recycle / dispose, engineering / construction, or installation.

Licenses and other proprietary specifications of access rights are also instances of this class.

Examples: A particular offering made by Miller Rentals Ltd. says that they (1) sell Volkswagen Golf convertibles, (2) lease out a particular Ford pick-up truck, and (3) dispose car wrecks of any make and model."""
    Buy: NamedNode
    """This gr:BusinessFunction indicates that the gr:BusinessEntity is in general interested in purchasing the specified gr:ProductOrService.
DEPRECATED. Use gr:seeks instead."""
    ByBankTransferInAdvance: NamedNode
    """Payment by bank transfer in advance, i.e., the offering gr:BusinessEntity will inform the buying party about their bank account details and will deliver the goods upon receipt of the due amount.
This is equivalent to payment by wire transfer."""
    ByInvoice: NamedNode
    """Payment by bank transfer after delivery, i.e., the offering gr:BusinessEntity will deliver first, inform the buying party about the due amount and their bank account details, and expect payment shortly after delivery."""
    COD: NamedNode
    """Collect on delivery / Cash on delivery - A payment method where the recipient of goods pays at the time of delivery. Usually, the amount of money is collected by the transportation company handling the goods."""
    Cash: NamedNode
    """Payment by cash upon delivery or pickup."""
    CheckInAdvance: NamedNode
    """Payment by sending a check in advance, i.e., the offering gr:BusinessEntity will deliver the goods upon receipt of a check over the due amount. There are variations in handling payment by check - sometimes, shipment will be upon receipt of the check as a document, sometimes the shipment will take place only upon successful crediting of the check."""
    ConstructionInstallation: NamedNode
    """This gr:BusinessFunction indicates that the gr:BusinessEntity offers (or seeks) the construction and/or installation of the specified gr:ProductOrService at the customer's location."""
    DHL: NamedNode
    """Delivery via the parcel service DHL."""
    DayOfWeek: NamedNode
    """The day of the week, used to specify  to which day the opening hours of a gr:OpeningHoursSpecification refer.

Examples: Monday, Tuesday, Wednesday,..."""
    DeliveryChargeSpecification: NamedNode
    """A delivery charge specification is a conceptual entity that specifies the additional costs asked for the delivery of a given gr:Offering using a particular gr:DeliveryMethod by the respective gr:BusinessEntity. A delivery charge specification is characterized by (1) a monetary amount per order, specified as a literal value of type float in combination with a currency, (2) the delivery method, (3) the target country or region, and (4)  whether this charge includes local sales taxes, namely VAT.
A gr:Offering may be linked to multiple gr:DeliveryChargeSpecification nodes that specify alternative charges for disjoint combinations of target countries or regions, and delivery methods.

Examples: Delivery by direct download is free of charge worldwide, delivery by UPS to Germany is 10 Euros per order, delivery by mail within the US is 5 Euros per order.

The total amount of this charge is specified as a float value of the gr:hasCurrencyValue property. The currency is specified via the gr:hasCurrency datatype property. Whether the price includes VAT or not is indicated by the gr:valueAddedTaxIncluded property. The gr:DeliveryMethod to which this charge applies is specified using the gr:appliesToDeliveryMethod object property. The region or regions to which this charge applies is specified using the gr:eligibleRegions property, which uses ISO 3166-1 and ISO 3166-2 codes.

If the price can only be given as a range, use gr:hasMaxCurrencyValue and gr:hasMinCurrencyValue for the upper and lower bounds.

Important: When querying for the price, always use gr:hasMaxCurrencyValue and gr:hasMinCurrencyValue."""
    DeliveryMethod: NamedNode
    """A delivery method is a standardized procedure for transferring the product or service to the destination of fulfilment chosen by the customer. Delivery methods are characterized by the means of transportation used, and by the organization or group that is the contracting party for the sending gr:BusinessEntity (this is important, since the contracted party may subcontract the fulfilment to smaller, regional businesses).

Examples: Delivery by mail, delivery by direct download, delivery by UPS"""
    DeliveryModeDirectDownload: NamedNode
    """Delivery of the goods via direct download from the Internet, i.e., the offering gr:BusinessEntity provides the buying party with details on how to retrieve the goods online. Connection fees and other costs of using the infrastructure are to be carried by the buying party."""
    DeliveryModeFreight: NamedNode
    """Delivery by an unspecified air, sea, or ground freight carrier or cargo company."""
    DeliveryModeMail: NamedNode
    """Delivery via regular mail service (private or public postal services)."""
    DeliveryModeOwnFleet: NamedNode
    """Delivery of the goods by using a fleet of vehicles either owned and operated or subcontracted by the gr:BusinessEntity."""
    DeliveryModeParcelService: NamedNode
    """A private parcel service as the delivery mode available for a certain offering.

Examples: UPS, DHL"""
    DeliveryModePickUp: NamedNode
    """Delivery of the goods by picking them up at one of the stores etc. (gr:Location) during the opening hours as specified by respective instances of gr:OpeningHoursSpecification."""
    DinersClub: NamedNode
    """Payment by credit or debit cards issued by the Diner's Club network."""
    DirectDebit: NamedNode
    """Payment by direct debit, i.e., the buying party will inform the offering gr:BusinessEntity about its bank account details and authorizes the gr:BusinessEntity to collect the agreed amount directly from that account."""
    Discover: NamedNode
    """Payment by credit or debit cards issued by the Discover network."""
    Dispose: NamedNode
    """This gr:BusinessFunction indicates that the gr:BusinessEntity offers (or seeks) the acceptance of the specified gr:ProductOrService for proper disposal, recycling, or any other kind of allowed usages, freeing the current owner from all rights and obligations of ownership."""
    Enduser: NamedNode
    """The gr:BusinessEntityType representing such agents that are purchasing the good or service for private consumption, in particular not for resale or for usage within an industrial enterprise. By default, a Business Entity is an Enduser."""
    FederalExpress: NamedNode
    """Delivery via the parcel service Federal Express."""
    Friday: NamedNode
    """Friday as a day of the week."""
    GoogleCheckout: NamedNode
    """Payment via the Google Checkout payment service."""
    Individual: NamedNode
    """A gr:Individual is an actual product or service instance, i.e., a single identifiable object or action that creates some increase in utility (in the economic sense) for the individual possessing or using this very object (product) or for the individual in whose favor this very action is being taken (service). Products or services are types of goods in the economic sense. For an overview of goods and commodities in economics, see Milgate (1987).

Examples: MyThinkpad T60, the pint of beer standing in front of me, my Volkswagen Golf, the haircut that I received or will be receiving at a given date and time.

Note 1: In many cases, product or service instances are not explicitly exposed on the Web but only claimed to exist (i.e. existentially quantified). In this case, use gr:SomeItems.
Note 2: This class is the new, shorter form of the former gr:ActualProductOrServiceInstance.

Compatibility with schema.org: This class is a subclass of http://schema.org/Product."""
    JCB: NamedNode
    """Payment by credit or debit cards issued by the JCB network."""
    LeaseOut: NamedNode
    """This gr:BusinessFunction indicates that the gr:BusinessEntity offers (or seeks) the temporary right to use the specified gr:ProductOrService."""
    License: NamedNode
    """A license is the specification of a bundle of rights that determines the type of activity or access offered by the gr:BusinessEntity on the gr:ProductOrService through the gr:Offering.
	
Licenses can be standardized (e.g. LPGL, Creative Commons, ...), vendor-specific, or individually defined for a single offer or product. Whether there is a fee for obtaining the license is specified using the gr:UnitPriceSpecification attached to the gr:Offering. Use foaf:page for linking to a document containing the license, e.g. in PDF or HTML."""
    Location: NamedNode
    """A location is a point or area of interest from which a particular product or service is available, e.g. a store, a bus stop, a gas station, or a ticket booth. The difference to gr:BusinessEntity is that the gr:BusinessEntity is the legal entity (e.g. a person or corporation) making the offer, while gr:Location is the store, office, or place. A chain restaurant will e.g. have one legal entity but multiple restaurant locations. Locations are characterized by an address or geographical position and a set of opening hour specifications for various days of the week.
		
Example: A rental car company may offer the Business Function Lease Out of cars from two locations, one in Fort Myers, Florida, and one in Boston, Massachussetts. Both stations are open 7:00 - 23:00 Mondays through Saturdays.

Note: Typical address standards (vcard) and location data (geo, WGC84) should be attached to a gr:Location node. Since there already exist established vocabularies for this, the GoodRelations ontology does not provide respective attributes. Instead, the use of respective vocabularies is recommended. However, the gr:hasGlobalLocationNumber property is  provided for linking to public identifiers for business locations.
		
Compatibility with schema.org: This class is equivalent to http://schema.org/Place."""
    LocationOfSalesOrServiceProvisioning: NamedNode
    """DEPRECATED - This class is superseded by gr:Location. Replace all occurrences of gr:LocationOfSalesOrServiceProvisioning by gr:Location, if possible."""
    Maintain: NamedNode
    """This gr:BusinessFunction indicates that the gr:BusinessEntity offers (or seeks) typical maintenance tasks for the specified gr:ProductOrService. Maintenance tasks are actions that undo or compensate for wear or other deterioriation caused by regular usage, in order to restore the originally intended function of the product, or to prevent outage or malfunction."""
    MasterCard: NamedNode
    """Payment by credit or debit cards issued by the MasterCard network."""
    Monday: NamedNode
    """Monday as a day of the week."""
    Offering: NamedNode
    """An offering represents the public, not necessarily binding, not necessarily exclusive, announcement by a gr:BusinessEntity to provide (or seek) a certain gr:BusinessFunction for a certain gr:ProductOrService to a specified target audience. An offering is specified by the type of product or service or bundle it refers to, what business function is being offered (sales, rental, ...), and a set of commercial properties. It can either refer to 
(1) a clearly specified instance (gr:Individual),
(2) to a set of anonymous instances of a given type (gr:SomeItems),
(3) a product model specification (gr:ProductOrServiceModel), see also section 3.3.3 of the GoodRelations Technical Report. 

An offering may be constrained in terms of the eligible type of business partner, countries, quantities, and other commercial properties. The definition of the commercial properties, the type of product offered, and the business function are explained in other parts of this vocabulary in more detail.

Example: Peter Miller offers to repair TV sets made by Siemens, Volkswagen Innsbruck sells a particular instance of a Volkswagen Golf at $10,000.

Compatibility with schema.org: This class is a superclass to http://schema.org/Offer, since gr:Offering can also represent demand."""
    OpeningHoursSpecification: NamedNode
    """This is a conceptual entity that holds together all information about the opening hours on a given day (gr:DayOfWeek)."""
    PayPal: NamedNode
    """Payment via the PayPal payment service."""
    PaySwarm: NamedNode
    """Payment via the PaySwarm distributed micropayment service."""
    PaymentChargeSpecification: NamedNode
    """A payment charge specification is a conceptual entity that specifies the additional costs asked for settling the payment after accepting a given gr:Offering using a particular gr:PaymentMethod. A payment charge specification is characterized by (1) a monetary amount per order specified as a literal value of type float in combination with a Currency, (2) the payment method, and (3) a whether this charge includes local sales taxes, namely VAT.
A gr:Offering may be linked to multiple payment charge specifications that specify alternative charges for various payment methods.

Examples: Payment by VISA or Mastercard costs a fee of 3 Euros including VAT, payment by bank transfer in advance is free of charge.

The total amount of this surcharge is specified as a float value of the gr:hasCurrencyValue property. The currency is specified via the gr:hasCurrency datatype property. Whether the price includes VAT or not is indicated by the gr:valueAddedTaxIncluded datatype property. The gr:PaymentMethod to which this charge applies is specified using the gr:appliesToPaymentMethod object property.

If the price can only be given as a range, use gr:hasMaxCurrencyValue and gr:hasMinCurrencyValue for the upper and lower bounds.

Important: When querying for the price, always use gr:hasMaxCurrencyValue and gr:hasMinCurrencyValue."""
    PaymentMethod: NamedNode
    """A payment method is a standardized procedure for transferring the monetary amount for a purchase. Payment methods are characterized by the legal and technical structures used, and by the organization or group carrying out the transaction. This element is mostly used for specifying the types of payment accepted by a gr:BusinessEntity.

Examples: VISA, MasterCard, Diners, cash, or bank transfer in advance."""
    PaymentMethodCreditCard: NamedNode
    """The subclass of gr:PaymentMethod represents all variants and brands of credit or debit cards as a standardized procedure for transferring the monetary amount for a purchase. It is mostly used for specifying the types of payment accepted by a gr:Business Entity.

Examples: VISA, MasterCard, or American Express."""
    PriceSpecification: NamedNode
    """The superclass of all price specifications."""
    ProductOrService: NamedNode
    """The superclass of all classes describing products or services types, either by nature or purpose. Examples for such subclasses are "TV set", "vacuum cleaner", etc. An instance of this class can be either an actual product or service (gr:Individual), a placeholder instance for unknown instances of a mass-produced commodity (gr:SomeItems), or a model / prototype specification (gr:ProductOrServiceModel). When in doubt, use gr:SomeItems.

Examples: 
a) MyCellphone123, i.e. my personal, tangible cell phone (gr:Individual)
b) Siemens1234, i.e. the Siemens cell phone make and model 1234 (gr:ProductOrServiceModel)
c) dummyCellPhone123 as a placeholder for actual instances of a certain kind of cell phones (gr:SomeItems)
	
Note: Your first choice for specializations of gr:ProductOrService should be http://www.productontology.org.

Compatibility with schema.org: This class is (approximately) equivalent to http://schema.org/Product."""
    ProductOrServiceModel: NamedNode
    """A product or service model is a intangible entity that specifies some characteristics of a group of similar, usually mass-produced products, in the sense of a prototype. In case of mass-produced products, there exists a relation gr:hasMakeAndModel between the actual product or service (gr:Individual or gr:SomeItems) and the prototype (gr:ProductOrServiceModel). GoodRelations treats product or service models as "prototypes" instead of a completely separate kind of entities, because this allows using the same domain-specific properties (e.g. gr:weight) for describing makes and models and for describing actual products.

Examples: Ford T, Volkswagen Golf, Sony Ericsson W123 cell phone

Note: An actual product or service (gr:Individual) by default shares the features of its model (e.g. the weight). However, this requires non-standard reasoning. See http://wiki.goodrelations-vocabulary.org/Axioms for respective rule sets.
	
Compatibility with schema.org: This class is (approximately) a subclass of http://schema.org/Product."""
    ProductOrServicesSomeInstancesPlaceholder: NamedNode
    """DEPRECATED - This class is superseded by gr:SomeItems. Replace all occurrences of gr:ProductOrServicesSomeInstancesPlaceholder by gr:SomeItems, if possible."""
    ProvideService: NamedNode
    """This gr:BusinessFunction indicates that the gr:BusinessEntity offers (or seeks) the respective type of service.

Note: Maintain and Repair are also types of Services. However, products and services ontologies often provide classes for tangible products as well as for types of services. The business function gr:ProvideService is to be used with such goods that are services, while gr:Maintain and gr:Repair can be used with goods for which only the class of product exists in the ontology, but not the respective type of service.

Example: Car maintenance could be expressed both as "provide the service car maintenance" or "maintain cars"."""
    PublicHolidays: NamedNode
    """A placeholder for all official public holidays at the gr:Location. This allows specifying the opening hours on public holidays. If a given day is a public holiday, this specification supersedes the opening hours for the respective day of the week."""
    PublicInstitution: NamedNode
    """The gr:BusinessEntityType representing such agents that are part of the adminstration or owned by the public."""
    QualitativeValue: NamedNode
    """A qualitative value is a predefined value for a product characteristic. 
	
Examples: the color "green" or the power cord plug type "US"; the garment sizes "S", "M", "L", and "XL".
	
Note: Value sets are supported by creating subclasses of this class. Ordinal relations between values (gr:greater, gr:lesser, ...) are provided directly by GoodRelations.

Compatibility with schema.org: This class is equivalent to http://schema.org/Enumeration."""
    QuantitativeValue: NamedNode
    """A quantitative value is a numerical interval that represents the range of a certain gr:quantitativeProductOrServiceProperty in terms of the lower and upper bounds for a particular gr:ProductOrService. It is to be interpreted in combination with the respective unit of measurement. Most quantitative values are intervals even if they are in practice often treated as a single point value.
	
Example: a weight between 10 and 25 kilogramms, a length between 10 and 15 milimeters.

Compatibility with schema.org: This class is equivalent to http://schema.org/Quantity."""
    QuantitativeValueFloat: NamedNode
    """An instance of this class is an actual float value for a quantitative property of a product. This instance is usually characterized by a minimal value, a maximal value, and a unit of measurement.

Examples: The intervals "between 10.0  and 25.4 kilogramms" or "10.2 and 15.5 milimeters".

Compatibility with schema.org: This class is a subclass of http://schema.org/Quantity."""
    QuantitativeValueInteger: NamedNode
    """An instance of this class is an actual integer value for a quantitative property of a product. This instance is usually characterized by a minimal value, a maximal value, and a unit of measurement. 

Example: A seating capacity between 1 and 8 persons.

Note: Users must keep in mind that ranges in here mean that ALL possible values in this interval are covered. (Sometimes, the actual commitment may be less than that: "We sell cars from 2 - 12 seats" does often not really mean that they have cars with 2,3,4,...12 seats.). Someone renting out two types of rowing boats, one that fits for 1 or 2 people, and another that must be operated by 4 people cannot claim to rent boats with a seating capacity between 1 and 4 people. He or she is offering two boat types for 1-2 and 4 persons.
		
Compatibility with schema.org: This class is a subclass of http://schema.org/Quantity."""
    Repair: NamedNode
    """This gr:BusinessFunction indicates that the gr:BusinessEntity offers (or seeks) the evaluation of the chances for repairing, and, if positive, repair of the specified gr:ProductOrService. Repairing means actions that restore the originally intended function of a product that suffers from outage or malfunction."""
    Reseller: NamedNode
    """The gr:BusinessEntityType representing such agents that are purchasing the scope of products included in the gr:Offering for resale on the market. Resellers are also businesses, i.e., they are officially registered with the public administration and strive for profits by their activities."""
    Saturday: NamedNode
    """Saturday as a day of the week."""
    Sell: NamedNode
    """This gr:BusinessFunction indicates that the gr:BusinessEntity offers to permanently transfer all property rights on the specified gr:ProductOrService."""
    SomeItems: NamedNode
    """A placeholder instance for unknown instances of a mass-produced commodity. This is used as a computationally cheap work-around for such instances that are not individually exposed on the Web but just stated to exist (i.e., which are existentially quantified).

Example: An instance of this class can represent an anonymous set of green Siemens1234 phones. It is different from the gr:ProductOrServiceModel Siemens1234, since this refers to the make and model, and it is different from a particular instance of this make and model (e.g. my individual phone) since the latter can be sold only once.

Note: This class is the new, shorter form of the former gr:ProductOrServicesSomeInstancesPlaceholder.
		
Compatibility with schema.org: This class is (approximately) a subclass of http://schema.org/Product."""
    Sunday: NamedNode
    """Sunday as a day of the week."""
    Thursday: NamedNode
    """Thursday as a day of the week."""
    Tuesday: NamedNode
    """Tuesday as a day of the week."""
    TypeAndQuantityNode: NamedNode
    """This class collates all the information about a gr:ProductOrService included in a bundle. If a gr:Offering contains just one item, you can directly link from the gr:Offering to the gr:ProductOrService using gr:includes. If the offering contains multiple items, use an instance of this class for each component to indicate the quantity, unit of measurement, and type of product, and link from the gr:Offering via gr:includesObject.

Example: An offering may include of 100g of Butter and 1 kg of potatoes, or 1 cell phone and 2 headsets."""
    UPS: NamedNode
    """Delivery via the parcel service UPS."""
    UnitPriceSpecification: NamedNode
    """A unit price specification is a conceptual entity that specifies the price asked for a given gr:Offering by the respective gr:Business Entity. An offering may be linked to multiple unit price specifications that specify alternative prices for non-overlapping sets of conditions (e.g. quantities or sales regions) or with differing validity periods. 

A unit price specification is characterized by (1) the lower and upper limits and the unit of measurement of the eligible quantity, (2) by a monetary amount per unit of the product or service, and (3)  whether this prices includes local sales taxes, namely VAT.
	
Example: The price, including VAT, for 1 kg of a given material is 5 Euros per kg for 0 - 5 kg and 4 Euros for quantities above 5 kg.

The eligible quantity interval for a given price is specified using the object property gr:hasEligibleQuantity, which points to an instance of gr:QuantitativeValue. The currency is specified using the gr:hasCurrency property, which points to an ISO 4217 currency code. The unit of measurement for the eligible quantity is specified using the gr:hasUnitOfMeasurement datatype property, which points to an UN/CEFACT Common Code (3 characters).
	
In most cases, the appropriate unit of measurement is the UN/CEFACT Common Code "C62" for "Unit or piece", since a gr:Offering is defined by the quantity and unit of measurement of all items included (e.g. "1 kg of bananas plus a 2 kg of apples"). As long at the offering consists of only one item, it is also possible to use an unit of measurement of choice for specifying the price per unit. For bundles, however, only  "C62" for "Unit or piece" is a valid unit of measurement.

You can assume that the price is given per unit or piece if there is no gr:hasUnitOfMeasurement property attached to the price.
	
Whether VAT and sales taxes are included in this price is specified using the property gr:valueAddedTaxIncluded (xsd:boolean).
	
The price per unit of measurement is specified as a float value of the gr:hasCurrencyValue property. The currency is specified via the gr:hasCurrency datatype property. Whether the price includes VAT or not is indicated by the gr:valueAddedTaxIncluded datatype property.

The property priceType can be used to indicate that the price is a retail price recommendation only (i.e. a list price). 

If the price can only be given as a range, use gr:hasMaxCurrencyValue and gr:hasMinCurrencyValue for the upper and lower bounds.

Important: When querying for the price, always use gr:hasMaxCurrencyValue and gr:hasMinCurrencyValue.

Note 1: Due to the complexity of pricing scenarios in various industries, it may be necessary to create extensions of this fundamental model of price specifications. Such can be done easily by importing and refining the GoodRelations ontology.

Note 2: For Google, attaching a gr:validThrough statement to a gr:UnitPriceSpecification is mandatory. 
"""
    VISA: NamedNode
    """Payment by credit or debit cards issued by the VISA network."""
    WarrantyPromise: NamedNode
    """This is a conceptual entity that holds together all aspects of the n-ary relation gr:hasWarrantyPromise.

A Warranty promise is an entity representing the duration and scope of services that will be provided to a customer free of charge in case of a defect or malfunction of the gr:ProductOrService. A warranty promise is characterized by its temporal duration (usually starting with the date of purchase) and its gr:WarrantyScope. The warranty scope represents the types of services provided (e.g. labor and parts, just parts) of the warranty included in an gr:Offering. The actual services may be provided by the gr:BusinessEntity making the offering, by the manufacturer of the product, or by a third party. There may be multiple warranty promises associated with a particular offering, which differ in duration and scope (e.g. pick-up service during the first 12 months, just parts and labor for 36 months).

Examples: 12 months parts and labor, 36 months parts"""
    WarrantyScope: NamedNode
    """The warranty scope represents types of services that will be provided free of charge by the vendor or manufacturer in the case of a defect (e.g. labor and parts, just parts), as part of the warranty included in an gr:Offering. The actual services may be provided by the gr:BusinessEntity making the offering, by the manufacturer of the product, or by a third party. 

Examples: Parts and Labor, Parts"""
    Wednesday: NamedNode
    """Wednesday as a day of the week."""
    acceptedPaymentMethods: NamedNode
    """The gr:PaymentMethod or methods accepted by the gr:BusinessEntity for the given gr:Offering."""
    addOn: NamedNode
    """This property points from a gr:Offering to additional offerings that can only be obtained in combination with the first offering. This can be used to model supplements and extensions that are available for a surcharge. Any gr:PriceSpecification attached to the secondary offering is to be understood as an additional charge."""
    advanceBookingRequirement: NamedNode
    """The minimal and maximal amount of time that is required between accepting the gr:Offering and the actual usage of the resource or service. This is mostly relevant for offers regarding hotel rooms, the rental of objects, or the provisioning of services. The duration is specified relatively to the beginning of the usage of the contracted object. It is represented by attaching an instance of the class gr:QuantitativeValueInteger. The lower and upper boundaries are specified using the properties gr:hasMinValueInteger and gr:hasMaxValueInteger to that instance. The unit of measurement is specified using the property gr:hasUnitOfMeasurement with a string holding a UN/CEFACT code suitable for durations, e.g. MON (months), DAY (days), HUR (hours), or MIN (minutes).

The difference to the gr:validFrom and gr:validThrough properties is that those specify the interval during which the gr:Offering is valid, while gr:advanceBookingRequirement specifies the acceptable relative amount of time between accepting the offer and the fulfilment or usage."""
    amountOfThisGood: NamedNode
    """This property specifies the quantity of the goods included in the gr:Offering via this gr:TypeAndQuantityNode. The quantity is given in the unit of measurement attached to the gr:TypeAndQuantityNode."""
    appliesToDeliveryMethod: NamedNode
    """This property specifies the gr:DeliveryMethod to which the gr:DeliveryChargeSpecification applies."""
    appliesToPaymentMethod: NamedNode
    """This property specifies the gr:PaymentMethod to which the gr:PaymentChargeSpecification applies."""
    availabilityEnds: NamedNode
    """This property specifies the end of the availability of the gr:ProductOrService included in the gr:Offering.
The difference to the properties gr:validFrom and gr:validThrough is that those specify the period of time during which the offer is valid and can be accepted.

Example: I offer to lease my boat for the period of August 1 - August 31, 2010, but you must accept by offer no later than July 15.

A time-zone should be specified. For a time in GMT/UTC, simply add a "Z" following the time:

2008-05-30T09:30:10Z.

Alternatively, you can specify an offset from the UTC time by adding a positive or negative time following the time:

2008-05-30T09:30:10-09:00

or

2008-05-30T09:30:10+09:00.

Note: There is another property gr:availableAtOrFrom, which is used to indicate the gr:Location (e.g. store or shop) from which the goods would be available."""
    availabilityStarts: NamedNode
    """This property specifies the beginning of the availability of the gr:ProductOrService included in the gr:Offering.
The difference to the properties gr:validFrom and gr:validThrough is that those specify the period of time during which the offer is valid and can be accepted.

Example: I offer to lease my boat for the period of August 1 - August 31, 2010, but you must accept by offer no later than July 15.

A time-zone should be specified. For a time in GMT/UTC, simply add a "Z" following the time:

2008-05-30T09:30:10Z.

Alternatively, you can specify an offset from the UTC time by adding a positive or negative time following the time:

2008-05-30T09:30:10-09:00

or

2008-05-30T09:30:10+09:00.

Note: There is another property gr:availableAtOrFrom, which is used to indicate the gr:Location (e.g. store or shop) from which the goods would be available."""
    availableAtOrFrom: NamedNode
    """This states that a particular gr:Offering is available at or from the given gr:Location (e.g. shop or branch)."""
    availableDeliveryMethods: NamedNode
    """This specifies the gr:DeliveryMethod or methods available for a given gr:Offering."""
    billingIncrement: NamedNode
    """This property specifies the minimal quantity and rounding increment that will be the basis for the billing. 
The unit of measurement is specified by the UN/CEFACT code attached to the gr:UnitPriceSpecification via the gr:hasUnitOfMeasurement property.

Examples: 
- The price for gasoline is 4 USD per gallon at the pump, but you will be charged in units of 0.1 gallons.
- The price for legal consulting is 100 USD per hour, but you will be charged in units of 15 minutes.

This property makes sense only for instances of gr:Offering that include not more than one type of good or service."""
    category: NamedNode
    """The name of a category to which this gr:ProductOrService, gr:Offering, gr:BusinessEntity, or gr:Location belongs.
	
Note 1: For products, it is better to add an rdf:type statement referring to a GoodRelations-compliant ontology for vertical industries instead, but if you just have a short text label, gr:category is simpler.
Note 2: You can use greater signs or slashes to informally indicate a category hierarchy, e.g. "restaurants/asian_restaurants" or "cables > usb_cables"
"""
    closes: NamedNode
    """The closing  hour of the gr:Location on the given gr:DayOfWeek.
If no time-zone suffix is included, the time is given in the local time valid at the gr:Location.

For a time in GMT/UTC, simply add a "Z" following the time:

09:30:10Z.

Alternatively, you can specify an offset from the UTC time by adding a positive or negative time following the time:

09:30:10-09:00

09:30:10+09:00.

Note 1: Use 00:00:00 for the first second of the respective day and 23:59:59 for the last second of that day.
Note 2: If a store opens at 17:00 on Saturdays and closes at 03:00:00 a.m. next morning, use two instances of this class, one with 17:00:00 - 23:59:59 for Saturday and another one with 00:00:00 - 03:00:00 for Sunday.
Note 3: If the shop re-opens on the same day of the week or set of days of the week, you must create a second instance of gr:OpeningHoursSpecification."""
    color: NamedNode
    """The color of the product."""
    condition: NamedNode
    """A textual description of the condition of the product or service, or the products or services included in the offer (when attached to a gr:Offering)"""
    datatypeProductOrServiceProperty: NamedNode
    """This property is the super property for all pure datatype properties that can be used to describe a gr:ProductOrService.

In products and services ontologies, only such properties that are no quantitative properties and that have no predefined gr:QualitativeValue instances are subproperties of this property. In practice, this refers to a few integer properties for which the integer value represents qualitative aspects, for string datatypes (as long as no predefined values exist), for boolean datatype properties, and for dates and times."""
    deliveryLeadTime: NamedNode
    """This property can be used to indicate the promised delay between the receipt of the order and the goods leaving the warehouse.

The duration is specified by attaching an instance of gr:QuantitativeValueInteger. The lower and upper boundaries are specified using the properties gr:hasMinValueInteger and gr:hasMaxValueInteger to that instance. A point value can be modeled with the gr:hasValueInteger property. The unit of measurement is specified using the property gr:hasUnitOfMeasurement with a string holding a UN/CEFACT code suitable for durations, e.g. MON (months), DAY (days), HUR (hours), or MIN (minutes)."""
    depth: NamedNode
    """The depth of the product.
Typical unit code(s): CMT for centimeters, INH for inches"""
    description: NamedNode
    """A short textual description of the resource. 

This property is semantically equivalent to rdfs:comment and just meant as a handy shortcut for marking up data."""
    displayPosition: NamedNode
    """The position at which the option or element should be listed in a menu or user dialog, lower numbers come first.

The main usage of this property are the days of the week (gr:DayOfWeek), but it is also possible to apply it e.g. to product features or any other conceptual element.
Note: Rely on this property only for data originating from a single RDF graph; otherwise, unpredictable results are possible."""
    durationOfWarrantyInMonths: NamedNode
    """This property specifies the duration of the gr:WarrantyPromise in months."""
    eligibleCustomerTypes: NamedNode
    """The types of customers (gr:BusinessEntityType) for which the given gr:Offering is valid."""
    eligibleDuration: NamedNode
    """The minimal and maximal duration for which the given gr:Offering or gr:License is valid. This is mostly used for offers regarding accommodation, the rental of objects, or software licenses. The duration is specified by attaching an instance of gr:QuantitativeValue. The lower and upper boundaries are specified using the properties gr:hasMinValue and gr:hasMaxValue to that instance. If they are the same, use the gr:hasValue property. The unit of measurement is specified using the property gr:hasUnitOfMeasurement with a string holding a UN/CEFACT code suitable for durations, e.g. MON (months), DAY (days), HUR (hours), or MIN (minutes).

The difference to the gr:validFrom and gr:validThrough properties is that those specify the absiolute interval during which the gr:Offering or gr:License is valid, while gr:eligibleDuration specifies the acceptable duration of the contract or usage."""
    eligibleRegions: NamedNode
    """This property specifies the geo-political region or regions for which the gr:Offering, gr:License, or gr:DeliveryChargeSpecification is valid using the two-character version of ISO 3166-1 (ISO 3166-1 alpha-2)  for regions or ISO 3166-2 , which breaks down the countries from ISO 3166-1 into administrative subdivisions.

Important: Do NOT use 3-letter ISO 3166-1 codes!"""
    eligibleTransactionVolume: NamedNode
    """This property can be used to indicate the transaction volume, in a monetary unit, for which the gr:Offering or gr:PriceSpecification is valid. This is mostly used to specify a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases above a certain amount.

The object is a gr:PriceSpecification that uses the properties gr:hasMaxCurrencyValue and gr:hasMinCurrencyValue to indicate the lower and upper boundaries and gr:hasCurrency to indicate the currency using the ISO 4217 standard (3 characters)."""
    equal: NamedNode
    """This ordering relation for qualitative values indicates that the subject is equal to the object."""
    greater: NamedNode
    """This ordering relation for qualitative values indicates that the subject is greater than the object."""
    greaterOrEqual: NamedNode
    """This ordering relation for qualitative values indicates that the subject is greater than or equal to the object."""
    hasBrand: NamedNode
    """This specifies the brand or brands (gr:Brand) associated with a gr:ProductOrService, or the brand or brands maintained by a gr:BusinessEntity."""
    hasBusinessFunction: NamedNode
    """This specifies the business function of the gr:Offering, i.e. whether the gr:BusinessEntity is offering to sell, to lease, or to repair the particular type of product. In the case of bundles, it is also possible to attach individual business functions to each gr:TypeAndQuantityNode. The business function of the main gr:Offering determines the business function for all included objects or services, unless a business function attached to a gr:TypeAndQuantityNode overrides it.
	
Note: While it is possible that an entity is offering multiple types of business functions for the same set of objects (e.g. rental and sales), this should usually not be stated by attaching multiple business functions to the same gr:Offering, since the gr:UnitPriceSpecification for the varying business functions will typically be very different."""
    hasCurrency: NamedNode
    """The currency for all prices in the gr:PriceSpecification given using the ISO 4217 standard (3 characters)."""
    hasCurrencyValue: NamedNode
    """This property specifies the amount of money for a price per unit, shipping charges, or payment charges. The currency and other relevant details are attached to the respective gr:PriceSpecification etc.

For a gr:UnitPriceSpecification, this is the price for one unit or bundle (as specified in the unit of measurement of the unit price specification) of the respective gr:ProductOrService. For a gr:DeliveryChargeSpecification or a gr:PaymentChargeSpecification, it is the price per delivery or payment.

GoodRelations also supports giving price information as intervals only. If this is needed, use gr:hasMaxCurrencyValue for the upper bound and gr:hasMinCurrencyValue for the lower bound. 

Using gr:hasCurrencyValue sets the upper and lower bounds to the same given value, i.e., x gr:hasCurrencyValue y implies x gr:hasMinCurrencyValue y, x gr:hasMaxCurrencyValue y."""
    hasDUNS: NamedNode
    """The Dun & Bradstreet DUNS number for identifying a gr:BusinessEntity. The Dun & Bradstreet DUNS is a nine-digit number used to identify legal entities (but usually not branches or locations of logistical importance only)."""
    hasEligibleQuantity: NamedNode
    """This specifies the interval and unit of measurement of ordering quantities for which the gr:Offering or gr:PriceSpecification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.
Note that if an offering is a bundle, i.e. it consists of more than one unit of a single type of good, or if the unit of measurement for the good is different from unit (Common Code C62), then gr:hasEligibleQuantity refers to units of this bundle. In other words, "C62" for "Units or pieces" is usually the appropriate unit of measurement."""
    hasGlobalLocationNumber: NamedNode
    """The Global Location Number (GLN, sometimes also referred to as International Location Number or ILN) of the respective gr:BusinessEntity or gr:Location.
The Global Location Number is a thirteen-digit number used to identify parties and physical locations."""
    hasISICv4: NamedNode
    """The International Standard of Industrial Classification of All Economic Activities (ISIC), Revision 4 code for a particular gr:BusinessEntity or gr:Location. See http://unstats.un.org/unsd/cr/registry/isic-4.asp for more information.

Note: While ISIC codes are sometimes misused for classifying products or services, they are designed and suited only for classifying business establishments."""
    hasInventoryLevel: NamedNode
    """This property specifies the current approximate inventory level for gr:SomeItems. The unit of measurement and the point value or interval are indicated using the attached gr:QuantitativeValueFloat instance.

This property can also be attached to a gr:Offering in cases where the included products are not modeled in more detail."""
    hasMPN: NamedNode
    """The Manufacturer Part Number or MPN is a unique identifier for a product, service, or bundle from the perspective of a particular manufacturer. MPNs can be assigned to products or product datasheets, or bundles. Accordingly, the domain of this property is the union of gr:ProductOrService (the common superclass of goods and datasheets), and gr:Offering.

Important: Be careful when assuming two products or services instances or offering instances to be identical based on the MPN. Since MPNs are unique only for the same gr:BusinessEntity, this holds only when the two MPN values refer to the same gr:BusinessEntity. Such can be done by taking into account the provenance of the data. 

Usually, the properties gr:hasEAN_UCC-13 and gr:hasGTIN-14 are much more reliable identifiers, because they are globally unique.

See also http://en.wikipedia.org/wiki/Part_number"""
    hasMakeAndModel: NamedNode
    """This states that an actual product instance (gr:Individual) or a placeholder instance for multiple, unidentified such instances (gr:SomeItems) is one occurence of a particular gr:ProductOrServiceModel.

Example: myFordT hasMakeAndModel FordT."""
    hasManufacturer: NamedNode
    """This object property links a gr:ProductOrService to the gr:BusinessEntity that produces it. Mostly used with gr:ProductOrServiceModel."""
    hasMaxCurrencyValue: NamedNode
    """This property specifies the UPPER BOUND of the amount of money for a price RANGE per unit, shipping charges, or payment charges. The currency and other relevant details are attached to the respective gr:PriceSpecification etc.
For a gr:UnitPriceSpecification, this is the UPPER BOUND for the price for one unit or bundle (as specified in the unit of measurement of the unit price specification) of the respective gr:ProductOrService. For a gr:DeliveryChargeSpecification or a gr:PaymentChargeSpecification, it is the UPPER BOUND of the price per delivery or payment.

Using gr:hasCurrencyValue sets the upper and lower bounds to the same given value, i.e., x gr:hasCurrencyValue y implies x gr:hasMinCurrencyValue y, x gr:hasMaxCurrencyValue y."""
    hasMaxValue: NamedNode
    """This property captures the upper limit of a gr:QuantitativeValue instance."""
    hasMaxValueFloat: NamedNode
    """This property captures the upper limit of a gr:QuantitativeValueFloat instance."""
    hasMaxValueInteger: NamedNode
    """This property captures the upper limit of a gr:QuantitativeValueInteger instance."""
    hasMinCurrencyValue: NamedNode
    """This property specifies the LOWER BOUND of the amount of money for a price RANGE per unit, shipping charges, or payment charges. The currency and other relevant details are attached to the respective gr:PriceSpecification etc.
For a gr:UnitPriceSpecification, this is the LOWER BOUND for the price for one unit or bundle (as specified in the unit of measurement of the unit price specification) of the respective gr:ProductOrService. For a gr:DeliveryChargeSpecification or a gr:PaymentChargeSpecification, it is the LOWER BOUND of the price per delivery or payment.

Using gr:hasCurrencyValue sets the upper and lower bounds to the same given value, i.e., x gr:hasCurrencyValue y implies x gr:hasMinCurrencyValue y, x gr:hasMaxCurrencyValue y."""
    hasMinValue: NamedNode
    """This property captures the lower limit of a gr:QuantitativeValue instance."""
    hasMinValueFloat: NamedNode
    """This property captures the lower limit of a gr:QuantitativeValueFloat instance."""
    hasMinValueInteger: NamedNode
    """This property captures the lower limit of a gr:QuantitativeValueInteger instance."""
    hasNAICS: NamedNode
    """The North American Industry Classification System (NAICS) code for a particular gr:BusinessEntity.
See http://www.census.gov/eos/www/naics/ for more details.

Note: While NAICS codes are sometimes misused for classifying products or services, they are designed and suited only for classifying business establishments."""
    hasNext: NamedNode
    """This ordering relation for gr:DayOfWeek indicates that the subject is directly followed by the object.

Example: Monday hasNext Tuesday

Since days of the week are a cycle, this property is not transitive."""
    hasOpeningHoursDayOfWeek: NamedNode
    """This specifies the gr:DayOfWeek to which the gr:OpeningHoursSpecification is related.

Note: Use multiple instances of gr:OpeningHoursSpecification for specifying the opening hours for multiple days if the opening hours differ."""
    hasOpeningHoursSpecification: NamedNode
    """This property links a gr:Location to a gr:OpeningHoursSpecification."""
    hasPOS: NamedNode
    """This property states that the respective gr:Location is a point of sale for the respective gr:BusinessEntity. It allows linking those two types of entities without the need for a particular gr:Offering."""
    hasPrevious: NamedNode
    """This ordering relation for gr:DayOfWeek indicates that the subject is directly preceeded by the object.

Example: Tuesday hasPrevious Monday

Since days of the week are a cycle, this property is not transitive."""
    hasPriceSpecification: NamedNode
    """This links a gr:Offering to a gr:PriceSpecification or specifications. There can be unit price specifications, payment charge specifications, and delivery charge specifications. For each type, multiple specifications for the same gr:Offering are possible, e.g. for different quantity ranges or for different currencies, or for different combinations of gr:DeliveryMethod and target destinations.

Recommended retail prices etc. can be marked by the gr:priceType property of the gr:UnitPriceSpecification."""
    hasStockKeepingUnit: NamedNode
    """The Stock Keeping Unit, or SKU is a unique identifier for a product, service, or bundle from the perspective of a particular supplier, i.e. SKUs are mostly assigned and serialized at the merchant level. 
Examples of SKUs are the ordering or parts numbers used by a particular Web shop or catalog.

Consequently, the domain of gr:hasStockKeepingUnit is the union of the classes gr:Offering and gr:ProductOrService. 
If attached to a gr:Offering, the SKU will usually reflect a merchant-specific identifier, i.e. one valid only for that particular retailer or shop. 
If attached to a gr:ProductOrServiceModel, the SKU can reflect either the identifier used by the merchant or the part number used by the official manufacturer of that part. For the latter, gr:hasMPN is a better choice.

Important: Be careful when assuming two products or services instances or offering instances to be identical based on the SKU. Since SKUs are unique only for the same gr:BusinessEntity, this can be assumed only when you are sure that the two SKU values refer to the same business entity. Such can be done by taking into account the provenance of the data. As long as instances of gr:Offering are concerned, you can also check that the offerings are being offered by the same gr:Business Entity.

Usually, the properties gr:hasEAN_UCC-13 and gr:hasGTIN-14 are much more reliable identifiers, because they are globally unique.

See also http://en.wikipedia.org/wiki/Stock_Keeping_Unit."""
    hasUnitOfMeasurement: NamedNode
    """The unit of measurement for a gr:QuantitativeValue, a gr:UnitPriceSpecification, or a gr:TypeAndQuantityNode given using the UN/CEFACT Common Code (3 characters)."""
    hasValue: NamedNode
    """This subproperty specifies that the upper and lower limit of the given gr:QuantitativeValue are identical and have the respective value. It is a shortcut for such cases where a quantitative property is (at least practically) a single point value and not an interval."""
    hasValueFloat: NamedNode
    """This subproperty specifies that the upper and lower limit of the given gr:QuantitativeValueFloat are identical and have the respective float value. It is a shortcut for such cases where a quantitative property is (at least practically) a single point value and not an interval."""
    hasValueInteger: NamedNode
    """This subproperty specifies that the upper and lower limit of the given gr:QuantitativeValueInteger are identical and have the respective integer value. It is a shortcut for such cases where a quantitative property is (at least practically) a single point value and not an interval."""
    hasWarrantyPromise: NamedNode
    """This specifies the gr:WarrantyPromise made by the gr:BusinessEntity for the given gr:Offering."""
    hasWarrantyScope: NamedNode
    """This states the gr:WarrantyScope of a given gr:WarrantyPromise."""
    height: NamedNode
    """The height of the product.
Typical unit code(s): CMT for centimeters, INH for inches"""
    includes: NamedNode
    """This object property is a shortcut for the original gr:includesObject property for the common case of having exactly one single gr:ProductOrService instance included in an Offering. 

When linking to an instance of gr:SomeItems or gr:Individual, it is equivalent to using a gr:TypeAndQuantityNode with gr:hasUnitOfMeasurement="C62"^^xsd:string and gr:amountOfThisGood="1.0"^^xsd:float for that good.

When linking to a gr:ProductOrServiceModel, it is equivalent to 
1. defining an blank node for a gr:SomeItems
2. linking that blank node via gr:hasMakeAndModel to the gr:ProductOrServiceModel, and
3. linking from the gr:Offering to that blank node using another blank node of type gr:TypeAndQuantityNode with gr:hasUnitOfMeasurement="C62"^^xsd:string and gr:amountOfThisGood="1.0"^^xsd:float for that good."""
    includesObject: NamedNode
    """This object property links a gr:Offering to one or multiple gr:TypeAndQuantityNode or nodes that specify the components that are included in the respective offer."""
    isAccessoryOrSparePartFor: NamedNode
    """This states that a particular gr:ProductOrService is an accessory or spare part for another product or service."""
    isConsumableFor: NamedNode
    """This states that a particular gr:ProductOrService is a consumable for another product or service."""
    isListPrice: NamedNode
    """This boolean attribute indicates whether a gr:UnitPriceSpecification is a list price (usually a vendor recommendation) or not. "true"  indicates it is a list price, "false" indicates it is not.
DEPRECATED. Use the gr:priceType property instead."""
    isSimilarTo: NamedNode
    """This states that a given gr:ProductOrService is similar to another product or service. Of course, this is a subjective statement; when interpreting it, the trust in the origin of the statement should be taken into account."""
    isVariantOf: NamedNode
    """This states that a particular gr:ProductOrServiceModel is a variant of another product or service model. It is pretty safe to infer that the variant inherits all gr:quantitativeProductOrServiceProperty, gr:qualitativeProductOrServiceProperty, and gr:datatypeProductOrServiceProperty values that are defined for the first gr:ProductOrServiceModel.

Example:
foo:Red_Ford_T_Model gr:isVariantOf foo:Ford_T_Model"""
    legalName: NamedNode
    """The legal name of the gr:BusinessEntity."""
    lesser: NamedNode
    """This ordering relation for gr:QualitativeValue pairs indicates that the subject is lesser than the object."""
    lesserOrEqual: NamedNode
    """This ordering relation for gr:QualitativeValue pairs indicates that the subject is lesser than or equal to the object."""
    name: NamedNode
    """A short text describing the respective resource.

This property is semantically equivalent to dcterms:title and rdfs:label and just meant as a handy shortcut for marking up data."""
    nonEqual: NamedNode
    """This ordering relation for gr:QualitativeValue pairs indicates that the subject is not equal to the object."""
    offers: NamedNode
    """This links a gr:BusinessEntity to the offers (gr:Offering) it makes. If you want to express interest in receiving offers, use gr:seeks instead."""
    opens: NamedNode
    """The opening hour of the gr:Location on the given gr:DayOfWeek.
If no time-zone suffix is included, the time is given in the local time valid at the gr:Location.

For a time in GMT/UTC, simply add a "Z" following the time:

09:30:10Z.

Alternatively, you can specify an offset from the UTC time by adding a positive or negative time following the time:

09:30:10-09:00

or

09:30:10+09:00.

Note 1: Use 00:00:00 for the first second of the respective day and 23:59:59 for the last second of that day.
Note 2: If a store opens at 17:00 on Saturdays and closes at 03:00:00 a.m. next morning, use 17:00:00 - 23:59:59 for Saturday and 00:00:00 - 03:00:00 for Sunday.
Note 3: If the shop re-opens on the same day of the week or set of days of the week, you must create a second instance of gr:OpeningHoursSpecification."""
    owns: NamedNode
    """This property indicates that a particular person or business owns a particular product. It can be used to expose the products in one's posession in order to empower recommender systems to suggest matching offers.

Note that the product must be an instance of the class gr:Individual.

This property can also be safely applied to foaf:Agent instances."""
    predecessorOf: NamedNode
    """This property indicates that the subject is a previous, often discontinued variant of the gr:ProductOrServiceModel used as the object.

Example: Golf III predecessorOf Golf IV

This relation is transitive."""
    priceType: NamedNode
    """This attribute can be used to distinguish multiple different price specifications for the same gr:Offering. It supersedes the former gr:isListPrice property. The following values are recommended:

The absence of this property marks the actual sales price.

SRP: "suggested retail price" - applicable for all sorts of a non-binding retail price recommendations, e.g. such published by the manufacturer or the distributor. This value replaces the former gr:isListPrice property.

INVOICE: The invoice price, mostly used in the car industry - this is the price a dealer pays to the manufacturer, excluding rebates and charges."""
    qualitativeProductOrServiceProperty: NamedNode
    """This is the super property of all qualitative properties for products and services. All properties in product or service ontologies for which gr:QualitativeValue instances are specified are subproperties of this property."""
    quantitativeProductOrServiceProperty: NamedNode
    """This is the super property of all quantitative  properties for products and services. All properties in product or service ontologies that specify quantitative characteristics, for which an interval is at least theoretically an appropriate value, are subproperties of this property."""
    relatedWebService: NamedNode
    """The URI of a SOAP or REST Web Service from which additional information about the gr:BusinessEntity, gr:Offering, gr:PriceSpecification, or gr:ProductOrService, or any other element,  can be obtained. The recommended range is xsd:anyURI i.e., the URI of a SOAP or REST Web Service.

In principle, any existing or upcoming vocabulary for Web Services can be used in combination with GoodRelations, because the association between (a) the service description and (b) the GoodRelations description can be found via the Web Service URI value used with this gr:relatedWebService property."""
    seeks: NamedNode
    """This links a gr:BusinessEntity to gr:Offering nodes that describe what the business entity is interested in (i.e., the buy side). If you want to express interest in offering something, use gr:offers instead. Note that this substitutes the former gr:BusinessFunction gr:Buy, which is now deprecated."""
    serialNumber: NamedNode
    """The serial number or any alphanumeric identifier of a particular product. Note that serial number are unique only for the same brand or the same model, so you cannot infer from two occurrences of the same serial number that the objects to which they are attached are identical.

This property can also be attached to a gr:Offering in cases where the included products are not modeled in more detail."""
    successorOf: NamedNode
    """This property indicates that the subject is a newer, often updated or improved variant of the gr:ProductOrServiceModel used as the object.

Example: Golf III successorOf Golf II

This relation is transitive."""
    taxID: NamedNode
    """The Tax / Fiscal ID of the gr:BusinessEntity, e.g. the TIN in the US or the CIF/NIF in Spain. It is usually assigned by the country of residence"""
    typeOfGood: NamedNode
    """This specifies the gr:ProductOrService that the gr:TypeAndQuantityNode is referring to."""
    validFrom: NamedNode
    """This property specifies the beginning of the validity of the gr:Offering, gr:PriceSpecification, gr:License, or gr:OpeningHoursSpecification.
A time-zone should be specified. For a time in GMT/UTC, simply add a "Z" following the time:

2008-05-30T09:30:10Z.

Alternatively, you can specify an offset from the UTC time by adding a positive or negative time following the time:

2008-05-30T09:30:10-09:00

or

2008-05-30T09:30:10+09:00.

Note: If multiple contradicting instances of a gr:Offering, gr:PriceSpecification, or gr:OpeningHoursSpecification exist, it is a good heuristics to assume that
1. Information with validity information for the respective period of time ranks higher than information without validity information.
2. Among conflicting nodes both having validity information, the one with the shorter validity span ranks higher."""
    validThrough: NamedNode
    """This property specifies the end of the validity of the gr:Offering, gr:PriceSpecification, gr:License, or gr:OpeningHoursSpecification.
A time-zone should be specified. For a time in GMT/UTC, simply add a "Z" following the time:

2008-05-30T09:30:10Z.

Alternatively, you can specify an offset from the UTC time by adding a positive or negative time following the time:

2008-05-30T09:30:10-09:00

or
2008-05-30T09:30:10+09:00.

Note 1: If multiple contradicting instances of a gr:Offering, gr:PriceSpecification, or gr:OpeningHoursSpecification exist, it is a good heuristics to assume that
1. Information with validity information for the respective period of time ranks higher than information without validity information.
2. Among conflicting nodes both having validity information, the one with the shorter validity span ranks higher.
Note 2: For Google, attaching a gr:validThrough statement to a gr:UnitPriceSpecification is mandatory. 
"""
    valueAddedTaxIncluded: NamedNode
    """This property specifies whether the applicable value-added tax (VAT)  is included in the price of the gr:PriceSpecification or not.

Note: This is a simple representation which may not properly reflect all details of local taxation."""
    valueReference: NamedNode
    """The superclass of properties that link a gr:QuantitativeValue or a gr:QualitativeValue to a second gr:QuantitativeValue or a gr:QualitativeValue that provides additional information on the original value. A good modeling practice is to define specializations of this property (e.g. foo:referenceTemperature) for your particular domain."""
    vatID: NamedNode
    """The Value-added Tax ID of the gr:BusinessEntity. See http://en.wikipedia.org/wiki/Value_added_tax_identification_number for details."""
    weight: NamedNode
    """The weight of the gr:ProductOrService.
Typical unit code(s): GRM for gram, KGM for kilogram, LBR for pound"""
    width: NamedNode
    """The width of the gr:ProductOrService.
Typical unit code(s): CMT for centimeters, INH for inches"""



import typing as t
import warnings
from functools import lru_cache

from pyoxigraph import NamedNode

__WELL_KNOWN_NAMESPACE_META_ATTR__: set[str] = {
    "_nsBaseIri",
    "_issueWarning",
    "_nonPyIdentifiers",
    "_withContainerMembershipProperty",
}

__WELL_KNOWN_IGNORED_ATTR__: set[str] = {
    "_pytestfixturefunction",  # pytest
}


class PredefinedNamespaceMeta(type):
    _nsBaseIri: str  # Namespace IRI base
    _issueWarning: bool = False  # Issue warning if the accessed local name is unknown
    _nonPyIdentifiers: t.Iterable[str] = (
        tuple()
    )  # Local names that aren't valid Python identifiers
    _withContainerMembershipProperty: bool = False  # For rdf:_1, rdf:_2, ...

    @lru_cache()
    def expand_with(cls, local_name: str) -> NamedNode:
        """Return the NamedNode with concatenated iri and `local_name`."""
        # Do not expand if this is a meta-attribute
        if local_name in __WELL_KNOWN_NAMESPACE_META_ATTR__:
            raise AttributeError("Private use")

        if (
            (cls._issueWarning)
            and local_name not in cls
            and local_name not in __WELL_KNOWN_IGNORED_ATTR__
        ):
            warnings.warn(
                f"Local name '{local_name}' unknown in {cls.__name__} ({cls!r})",
                stacklevel=3,
            )

        return NamedNode(cls._nsBaseIri + local_name)

    def __getitem__(cls, name: str) -> NamedNode:
        """Return a NamedNode when called as `ns[key]`; an alternative to the `ns.key`
        syntax if `key` is not a valid Python identifier OR is a dunder name.
        """
        return cls.expand_with(name)

    def __getattr__(cls, name: str) -> NamedNode:
        """Return a NamedNode when called as`ns.key`."""
        # Only called for non-existing attributes, unlike __getattributes__
        # so not-implemented Python protocols should be skipped
        if name.startswith("__") and name.endswith("__"):
            raise AttributeError("Use the ns[...] syntax for dunder namespaced terms.")
        return cls.expand_with(name)

    def __contains__(cls, name: str) -> bool:
        """To be contained is considered for localnames in c.__annotations__ or
        the extended set in _nonPyIdentifiers.

        Enable rdf:_1, rdf:_2 with _withContainerMembershipProperty = True.
        """
        name = name.removeprefix(cls._nsBaseIri)
        return any(
            (
                name in c.__annotations__
                or name in c._nonPyIdentifiers
                or (
                    cls._withContainerMembershipProperty
                    and name[0] == "_"
                    and name[1:].isdigit()
                )
            )
            for c in cls.mro()
            if issubclass(c, PredefinedNamespace)
        )

    def __repr__(cls) -> str:
        return f"Namespace('{cls._nsBaseIri}')"


class PredefinedNamespace(metaclass=PredefinedNamespaceMeta):
    """Namespace with an optionally predefined list of known members.

    Returns a NamedNode when accessing local names either with dot-access or indexed
    access.

        >>> RDFS = Prefix("http://www.w3.org/2000/01/rdf-schema#")
        >>> RDFS.Class
        <NamedNode value=http://www.w3.org/2000/01/rdf-schema#Class>
        >>> RDFS['label']
        <NamedNode value=http://www.w3.org/2000/01/rdf-schema#label>

    Warnings may be issued if the local name is unknown:

        >>> RDFS['hello,world']
        <stdin>:1: UserWarning: Local name 'hello,world' unknown in RDF (Namespace('http://www.w3.org/2000/01/rdf-schema#'))
        <NamedNode value=http://www.w3.org/1999/02/22-rdf-syntax-ns#label>
    """

    def __init__(self):
        raise TypeError("Predefined namespaces can't be instantiated.")


def Prefix(iri: str) -> type[PredefinedNamespace]:
    """Define a namespace alias."""

    class MyNamespace(PredefinedNamespace):
        _nsBaseIri = iri

    return MyNamespace



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class XML(PredefinedNamespace):
    """XML Namespace"""

    _nsBaseIri = "http://www.w3.org/XML/1998/namespace"
    _issueWarning = True

    # Handwritten

    lang: NamedNode
    """Designed for identifying the human language used in the scope of the element to which it's attached."""
    space: NamedNode
    """Designed to express whether or not the document's creator wishes white space to be considered as significant in the scope of the element to which it's attached."""
    base: NamedNode
    """The XML Base specification (Second edition) describes a facility, similar to that of HTML BASE, for defining base URIs for parts of XML documents. It defines a single attribute, xml:base, and describes in detail the procedure for its use in processing relative URI refeferences. """
    id: NamedNode
    """The xml:id specification defines a single attribute, xml:id, known to be of type ID independently of any DTD or schema."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class SD(PredefinedNamespace):
    """SPARQL 1.1 Service Description"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/ns/sparql-service-description.ttl

    _nsBaseIri = "http://www.w3.org/ns/sparql-service-description#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Aggregate: NamedNode
    """An instance of sd:Aggregate represents an aggregate that may be used in a SPARQL aggregate query (for instance in a HAVING clause or SELECT expression) besides the standard list of supported aggregates COUNT, SUM, MIN, MAX, AVG, GROUP_CONCAT, and SAMPLE."""
    BasicFederatedQuery: NamedNode
    """sd:BasicFederatedQuery, when used as the object of the sd:feature property, indicates that the SPARQL service supports basic federated query using the SERVICE keyword as defined by SPARQL 1.1 Federation Extensions."""
    Dataset: NamedNode
    """An instance of sd:Dataset represents a RDF Dataset comprised of a default graph and zero or more named graphs."""
    DereferencesURIs: NamedNode
    """sd:DereferencesURIs, when used as the object of the sd:feature property, indicates that a SPARQL service will dereference URIs used in FROM/FROM NAMED and USING/USING NAMED clauses and use the resulting RDF in the dataset during query evaluation."""
    EmptyGraphs: NamedNode
    """sd:EmptyGraphs, when used as the object of the sd:feature property, indicates that the underlying graph store supports empty graphs. A graph store that supports empty graphs MUST NOT remove graphs that are left empty after triples are removed from them."""
    EntailmentProfile: NamedNode
    """An instance of sd:EntailmentProfile represents a profile of an entailment regime. An entailment profile MAY impose restrictions on what constitutes valid RDF with respect to entailment."""
    EntailmentRegime: NamedNode
    """An instance of sd:EntailmentRegime represents an entailment regime used in basic graph pattern matching (as described by SPARQL 1.1 Query Language)."""
    Feature: NamedNode
    """An instance of sd:Feature represents a feature of a SPARQL service. Specific types of features include functions, aggregates, languages, and entailment regimes and profiles. This document defines five instances of sd:Feature: sd:DereferencesURIs, sd:UnionDefaultGraph, sd:RequiresDataset, sd:EmptyGraphs, and sd:BasicFederatedQuery."""
    Function: NamedNode
    """An instance of sd:Function represents a function that may be used in a SPARQL SELECT expression or a FILTER, HAVING, GROUP BY, ORDER BY, or BIND clause."""
    Graph: NamedNode
    """An instance of sd:Graph represents the description of an RDF graph."""
    GraphCollection: NamedNode
    """An instance of sd:GraphCollection represents a collection of zero or more named graph descriptions. Each named graph description belonging to an sd:GraphCollection MUST be linked with the sd:namedGraph predicate."""
    Language: NamedNode
    """An instance of sd:Language represents one of the SPARQL languages, including specific configurations providing particular features or extensions. This document defines three instances of sd:Language: sd:SPARQL10Query, sd:SPARQL11Query, and sd:SPARQL11Update."""
    NamedGraph: NamedNode
    """An instance of sd:NamedGraph represents a named graph having a name (via sd:name) and an optional graph description (via sd:graph)."""
    RequiresDataset: NamedNode
    """sd:RequiresDataset, when used as the object of the sd:feature property, indicates that the SPARQL service requires an explicit dataset declaration (based on either FROM/FROM NAMED clauses in a query, USING/USING NAMED clauses in an update, or the appropriate SPARQL Protocol parameters)."""
    SPARQL10Query: NamedNode
    """sd:SPARQL10Query is an sd:Language representing the SPARQL 1.0 Query language."""
    SPARQL11Query: NamedNode
    """sd:SPARQL11Query is an sd:Language representing the SPARQL 1.1 Query language."""
    SPARQL11Update: NamedNode
    """sd:SPARQLUpdate is an sd:Language representing the SPARQL 1.1 Update language."""
    Service: NamedNode
    """An instance of sd:Service represents a SPARQL service made available via the SPARQL Protocol."""
    UnionDefaultGraph: NamedNode
    """sd:UnionDefaultGraph, when used as the object of the sd:feature property, indicates that the default graph of the dataset used during query and update evaluation (when an explicit dataset is not specified) is comprised of the union of all the named graphs in that dataset."""
    availableGraphs: NamedNode
    """Relates an instance of sd:Service to a description of the graphs which are allowed in the construction of a dataset either via the SPARQL Protocol, with FROM/FROM NAMED clauses in a query, or with USING/USING NAMED in an update request, if the service limits the scope of dataset construction."""
    defaultDataset: NamedNode
    """Relates an instance of sd:Service to a description of the default dataset available when no explicit dataset is specified in the query, update request or via protocol parameters."""
    defaultEntailmentRegime: NamedNode
    """Relates an instance of sd:Service with a resource representing an entailment regime used for basic graph pattern matching. This property is intended for use when a single entailment regime by default applies to all graphs in the default dataset of the service. In situations where a different entailment regime applies to a specific graph in the dataset, the sd:entailmentRegime property should be used to indicate this fact in the description of that graph."""
    defaultGraph: NamedNode
    """Relates an instance of sd:Dataset to the description of its default graph."""
    defaultSupportedEntailmentProfile: NamedNode
    """Relates an instance of sd:Service with a resource representing a supported profile of the default entailment regime (as declared by sd:defaultEntailmentRegime)."""
    endpoint: NamedNode
    """The SPARQL endpoint of an sd:Service that implements the SPARQL Protocol service. The object of the sd:endpoint property is an IRI."""
    entailmentRegime: NamedNode
    """Relates a named graph description with a resource representing an entailment regime used for basic graph pattern matching over that graph."""
    extensionAggregate: NamedNode
    """Relates an instance of sd:Service to an aggregate that may be used in a SPARQL aggregate query (for instance in a HAVING clause or SELECT expression) besides the standard list of supported aggregates COUNT, SUM, MIN, MAX, AVG, GROUP_CONCAT, and SAMPLE"""
    extensionFunction: NamedNode
    """Relates an instance of sd:Service to a function that may be used in a SPARQL SELECT expression or a FILTER, HAVING, GROUP BY, ORDER BY, or BIND clause."""
    feature: NamedNode
    """Relates an instance of sd:Service with a resource representing a supported feature."""
    graph: NamedNode
    """Relates a named graph to its graph description."""
    inputFormat: NamedNode
    """Relates an instance of sd:Service to a format that is supported for parsing RDF input; for example, via a SPARQL 1.1 Update LOAD statement, or when URIs are dereferenced in FROM/FROM NAMED/USING/USING NAMED clauses."""
    languageExtension: NamedNode
    """Relates an instance of sd:Service to a resource representing an implemented extension to the SPARQL Query or Update language."""
    name: NamedNode
    """Relates a named graph to the name by which it may be referenced in a FROM/FROM NAMED clause. The object of the sd:name property is an IRI."""
    namedGraph: NamedNode
    """Relates an instance of sd:GraphCollection (or its subclass sd:Dataset) to the description of one of its named graphs. The description of such a named graph MUST include the sd:name property and MAY include the sd:graph property."""
    propertyFeature: NamedNode
    """Relates an instance of sd:Service to a resource representing an implemented feature that extends the SPARQL Query or Update language and that is accessed by using the named property."""
    resultFormat: NamedNode
    """Relates an instance of sd:Service to a format that is supported for serializing query results."""
    supportedEntailmentProfile: NamedNode
    """Relates a named graph description with a resource representing a supported profile of the entailment regime (as declared by sd:entailmentRegime) used for basic graph pattern matching over that graph."""
    supportedLanguage: NamedNode
    """Relates an instance of sd:Service to a SPARQL language (e.g. Query and Update) that it implements."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class DQV(PredefinedNamespace):
    """Data Quality Vocabulary"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/ns/dqv.ttl

    _nsBaseIri = "http://www.w3.org/ns/dqv#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Category: NamedNode
    """Represents a group of quality dimensions in which a common type of information is used as quality indicator."""
    Dimension: NamedNode
    """Represents criteria relevant for assessing quality. Each quality dimension must have one or more metric to measure it. A dimension is linked with a category using the dqv:inCategory property."""
    Metric: NamedNode
    """Represents a standard to measure a quality dimension. An observation (instance of dqv:QualityMeasurement) assigns a value in a given unit to a Metric."""
    QualityAnnotation: NamedNode
    """Represents quality annotations, including ratings, quality certificates or feedback that can be associated to datasets or distributions. Quality annotations must have one oa:motivatedBy statement with an instance of oa:Motivation (and skos:Concept) that reflects a quality assessment purpose. We define this instance as dqv:qualityAssessment."""
    QualityCertificate: NamedNode
    """An annotation that associates a resource (especially, a dataset or a distribution) to another resource (for example, a document) that certifies the resource's quality according to a set of quality assessment rules."""
    QualityMeasurement: NamedNode
    """Represents the evaluation of a given dataset (or dataset distribution) against a specific quality metric."""
    QualityMeasurementDataset: NamedNode
    """Represents a dataset of quality measurements, evaluations of one or more datasets (or dataset distributions) against specific quality metrics."""
    QualityMetadata: NamedNode
    """Represents quality metadata, it is defined to group quality certificates, policies, measurements and annotations under a named graph."""
    QualityPolicy: NamedNode
    """Represents a policy or agreement that is chiefly governed by data quality concerns."""
    UserQualityFeedback: NamedNode
    """Represents feedback that users have on the quality of datasets or distributions. Besides dqv:qualityAssessment, which is the motivation required by all quality annotations, one of the predefined instances of oa:Motivation should be indicated as motivation to distinguish among the different kinds of feedback, e.g., classifications, questions."""
    computedOn: NamedNode
    """Refers to the resource (e.g., a dataset, a linkset, a graph, a set of triples) on which the quality measurement is performed. In the DQV context, this property is generally expected to be used in statements in which objects are instances of dcat:Dataset or dcat:Distribution."""
    expectedDataType: NamedNode
    """Represents the expected data type for metric's observed value (e.g. xsd:boolean, xsd:double etc...)"""
    hasQualityAnnotation: NamedNode
    """Refers to a quality annotation. Quality annotation can be applied to any kind of resource, e.g., a dataset, a linkset, a graph, a set of triples. However, in the DQV context, this property is generally expected to be used in statements in which subjects are instances of dcat:Dataset or dcat:Distribution."""
    hasQualityMeasurement: NamedNode
    """Refers to the performed quality measurements. Quality measurements can be performed to any kind of resource (e.g., a dataset, a linkset, a graph, a set of triples). However, in the DQV context, this property is generally expected to be used in statements in which subjects are instances of dcat:Dataset or dcat:Distribution."""
    hasQualityMetadata: NamedNode
    """Refers to a grouping of quality information such as certificates, policies, measurements and annotations as a named graph. Quality information represented in such a grouping can pertain to any kind of resource (e.g., a dataset, a linkset, a graph, a set of triples). However, in the DQV context, this property is generally expected to be used in statements in which subjects are instances of dcat:Dataset or dcat:Distribution."""
    inCategory: NamedNode
    """Represents the category a dimension is grouped in."""
    inDimension: NamedNode
    """Represents the dimensions a quality metric, certificate and annotation allow a measurement of."""
    isMeasurementOf: NamedNode
    """Indicates the metric being observed."""
    precision: NamedNode
    """Precision is a quality dimension, which refers to the recorded level of details. It represents the exactness of a measurement or description. It is equivalent the notion of Precision from ISO 25012."""
    qualityAssessment: NamedNode
    """Motivation that must be specified for quality annotations."""
    value: NamedNode
    """Refers to values computed by metric."""



import pytest
from pyoxigraph import NamedNode

from pyrdf_prefix import PredefinedNamespace, Prefix
from pyrdf_prefix.predefined import DCTERMS, RDF


def test_expansion():
    ex = Prefix("http://example.org/ns#")

    assert ex.Foo == NamedNode(value="http://example.org/ns#Foo")
    assert ex["Bar-Baz"] == NamedNode(value="http://example.org/ns#Bar-Baz")


def test_cant_init():
    class MyTestingClass(PredefinedNamespace): ...

    with pytest.raises(TypeError):
        MyTestingClass()


def test_dunder_raise():
    py = Prefix("http://example.org/python/")

    with pytest.raises(AttributeError):
        py.__bool__

    py["__bool__"]


def test_warnings():
    with pytest.warns():
        RDF["hello,world"]

    assert RDF.type == NamedNode("http://www.w3.org/1999/02/22-rdf-syntax-ns#type")


def test_nonpyids():
    # doesn't warn
    DCTERMS["ISO639-3"]

    with pytest.warns():
        DCTERMS["ISO639-3_"]



"""Predefined aliases are taken from the RDFa Core Initial Context [1] and supplemented
with ontologies that have been predefined in other namespace libraries.

Generated using src/utils/generate_predefined.py in the pyrdf-prefix repo.

Source: https://www.w3.org/2011/rdfa-context/rdfa-1.1
"""

from ._AS import AS
from ._BRICK import BRICK
from ._CC import CC
from ._CSVW import CSVW
from ._CTAG import CTAG
from ._DC import DC
from ._DC11 import DC11
from ._DCAM import DCAM
from ._DCAT import DCAT
from ._DCMITYPE import DCMITYPE
from ._DCTERMS import DCTERMS
from ._DOAP import DOAP
from ._DQV import DQV
from ._DUV import DUV
from ._FOAF import FOAF
from ._GEO import GEO
from ._GR import GR
from ._GRDDL import GRDDL
from ._ICAL import ICAL
from ._JSONLD import JSONLD
from ._LDP import LDP
from ._MA import MA
from ._OA import OA
from ._ODRL import ODRL
from ._OG import OG
from ._ORG import ORG
from ._OWL import OWL
from ._PROF import PROF
from ._PROV import PROV
from ._QB import QB
from ._RDF import RDF
from ._RDFA import RDFA
from ._RDFS import RDFS
from ._REV import REV
from ._RIF import RIF
from ._RR import RR
from ._SCHEMA import SCHEMA
from ._SD import SD
from ._SH import SH
from ._SIOC import SIOC
from ._SKOS import SKOS
from ._SKOSXL import SKOSXL
from ._SOSA import SOSA
from ._SSN import SSN
from ._TIME import TIME
from ._V import V
from ._VANN import VANN
from ._VCARD import VCARD
from ._VOID import VOID
from ._WDR import WDR
from ._WDRS import DESCRIBEDBY, WDRS
from ._WGS import WGS
from ._XHV import LICENSE, ROLE, XHV
from ._XML import XML
from ._XSD import XSD

__all__ = [
    "AS",
    "BRICK",
    "CC",
    "CSVW",
    "CTAG",
    "DC",
    "DC11",
    "DCAM",
    "DCAT",
    "DCMITYPE",
    "DCTERMS",
    "DESCRIBEDBY",
    "DOAP",
    "DQV",
    "DUV",
    "FOAF",
    "GEO",
    "GR",
    "GRDDL",
    "ICAL",
    "JSONLD",
    "LDP",
    "LICENSE",
    "MA",
    "OA",
    "ODRL",
    "OG",
    "ORG",
    "OWL",
    "PROF",
    "PROV",
    "QB",
    "RDF",
    "RDFA",
    "RDFS",
    "REV",
    "RIF",
    "ROLE",
    "RR",
    "SCHEMA",
    "SD",
    "SH",
    "SIOC",
    "SKOS",
    "SKOSXL",
    "SOSA",
    "SSN",
    "TIME",
    "V",
    "VANN",
    "VCARD",
    "VOID",
    "WDR",
    "WDRS",
    "WGS",
    "XHV",
    "XML",
    "XSD",
]



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class OA(PredefinedNamespace):
    """Web Annotation"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/ns/oa.ttl

    _nsBaseIri = "http://www.w3.org/ns/oa#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Annotation: NamedNode
    """The class for Web Annotations."""
    Choice: NamedNode
    """A subClass of  as:OrderedCollection  that conveys to a consuming application that it should select one of the resources in the  as:items  list to use, rather than all of them.  This is typically used to provide a choice of resources to render to the user, based on further supplied properties.  If the consuming application cannot determine the user's preference, then it should use the first in the list."""
    CssSelector: NamedNode
    """A CssSelector describes a Segment of interest in a representation that conforms to the Document Object Model through the use of the CSS selector specification."""
    CssStyle: NamedNode
    """A resource which describes styles for resources participating in the Annotation using CSS."""
    DataPositionSelector: NamedNode
    """DataPositionSelector describes a range of data by recording the start and end positions of the selection in the stream. Position 0 would be immediately before the first byte, position 1 would be immediately before the second byte, and so on. The start byte is thus included in the list, but the end byte is not."""
    Direction: NamedNode
    """A class to encapsulate the different text directions that a textual resource might take.  It is not used directly in the Annotation Model, only its three instances."""
    FragmentSelector: NamedNode
    """The FragmentSelector class is used to record the segment of a representation using the IRI fragment specification defined by the representation's media type."""
    HttpRequestState: NamedNode
    """The HttpRequestState class is used to record the HTTP request headers that a client SHOULD use to request the correct representation from the resource. """
    Motivation: NamedNode
    """The Motivation class is used to record the user's intent or motivation for the creation of the Annotation, or the inclusion of the body or target, that it is associated with."""
    PreferContainedDescriptions: NamedNode
    """An IRI to signal the client prefers to receive full descriptions of the Annotations from a container, not just their IRIs."""
    PreferContainedIRIs: NamedNode
    """An IRI to signal that the client prefers to receive only the IRIs of the Annotations from a container, not their full descriptions."""
    RangeSelector: NamedNode
    """A Range Selector can be used to identify the beginning and the end of the selection by using other Selectors. The selection consists of everything from the beginning of the starting selector through to the beginning of the ending selector, but not including it."""
    ResourceSelection: NamedNode
    """Instances of the ResourceSelection class identify part (described by an oa:Selector) of another resource (referenced with oa:hasSource), possibly from a particular representation of a resource (described by an oa:State). Please note that ResourceSelection is not used directly in the Web Annotation model, but is provided as a separate class for further application profiles to use, separate from oa:SpecificResource which has many Annotation specific features."""
    Selector: NamedNode
    """A resource which describes the segment of interest in a representation of a Source resource, indicated with oa:hasSelector from the Specific Resource. This class is not used directly in the Annotation model, only its subclasses."""
    SpecificResource: NamedNode
    """Instances of the SpecificResource class identify part of another resource (referenced with oa:hasSource), a particular representation of a resource, a resource with styling hints for renders, or any combination of these, as used within an Annotation."""
    State: NamedNode
    """A State describes the intended state of a resource as applied to the particular Annotation, and thus provides the information needed to retrieve the correct representation of that resource."""
    Style: NamedNode
    """A Style describes the intended styling of a resource as applied to the particular Annotation, and thus provides the information to ensure that rendering is consistent across implementations."""
    SvgSelector: NamedNode
    """An SvgSelector defines an area through the use of the Scalable Vector Graphics [SVG] standard. This allows the user to select a non-rectangular area of the content, such as a circle or polygon by describing the region using SVG. The SVG may be either embedded within the Annotation or referenced as an External Resource."""
    TextPositionSelector: NamedNode
    """The TextPositionSelector describes a range of text by recording the start and end positions of the selection in the stream. Position 0 would be immediately before the first character, position 1 would be immediately before the second character, and so on."""
    TextQuoteSelector: NamedNode
    """The TextQuoteSelector describes a range of text by copying it, and including some of the text immediately before (a prefix) and after (a suffix) it to distinguish between multiple copies of the same sequence of characters."""
    TextualBody: NamedNode
    """"""
    TimeState: NamedNode
    """A TimeState records the time at which the resource's state is appropriate for the Annotation, typically the time that the Annotation was created and/or a link to a persistent copy of the current version."""
    XPathSelector: NamedNode
    """ An XPathSelector is used to select elements and content within a resource that supports the Document Object Model via a specified XPath value."""
    annotationService: NamedNode
    """The object of the relationship is the end point of a service that conforms to the annotation-protocol, and it may be associated with any resource.  The expectation of asserting the relationship is that the object is the preferred service for maintaining annotations about the subject resource, according to the publisher of the relationship.

  This relationship is intended to be used both within Linked Data descriptions and as the  rel  type of a Link, via HTTP Link Headers rfc5988 for binary resources and in HTML <link> elements.  For more information about these, please see the Annotation Protocol specification annotation-protocol.
  """
    assessing: NamedNode
    """The motivation for when the user intends to provide an assessment about the Target resource."""
    bodyValue: NamedNode
    """The object of the predicate is a plain text string to be used as the content of the body of the Annotation.  The value MUST be an  xsd:string  and that data type MUST NOT be expressed in the serialization. Note that language MUST NOT be associated with the value either as a language tag, as that is only available for  rdf:langString .
  """
    bookmarking: NamedNode
    """The motivation for when the user intends to create a bookmark to the Target or part thereof."""
    cachedSource: NamedNode
    """A object of the relationship is a copy of the Source resource's representation, appropriate for the Annotation."""
    canonical: NamedNode
    """A object of the relationship is the canonical IRI that can always be used to deduplicate the Annotation, regardless of the current IRI used to access the representation."""
    classifying: NamedNode
    """The motivation for when the user intends to that classify the Target as something."""
    commenting: NamedNode
    """The motivation for when the user intends to comment about the Target."""
    describing: NamedNode
    """The motivation for when the user intends to describe the Target, as opposed to a comment about them."""
    editing: NamedNode
    """The motivation for when the user intends to request a change or edit to the Target resource."""
    end: NamedNode
    """The end property is used to convey the 0-based index of the end position of a range of content."""
    exact: NamedNode
    """The object of the predicate is a copy of the text which is being selected, after normalization."""
    hasBody: NamedNode
    """The object of the relationship is a resource that is a body of the Annotation."""
    hasEndSelector: NamedNode
    """The relationship between a RangeSelector and the Selector that describes the end position of the range. """
    hasPurpose: NamedNode
    """The purpose served by the resource in the Annotation."""
    hasScope: NamedNode
    """The scope or context in which the resource is used within the Annotation."""
    hasSelector: NamedNode
    """The object of the relationship is a Selector that describes the segment or region of interest within the source resource.  Please note that the domain ( oa:ResourceSelection ) is not used directly in the Web Annotation model."""
    hasSource: NamedNode
    """The resource that the ResourceSelection, or its subclass SpecificResource, is refined from, or more specific than. Please note that the domain ( oa:ResourceSelection ) is not used directly in the Web Annotation model."""
    hasStartSelector: NamedNode
    """The relationship between a RangeSelector and the Selector that describes the start position of the range. """
    hasState: NamedNode
    """The relationship between the ResourceSelection, or its subclass SpecificResource, and a State resource. Please note that the domain ( oa:ResourceSelection ) is not used directly in the Web Annotation model."""
    hasTarget: NamedNode
    """The relationship between an Annotation and its Target."""
    highlighting: NamedNode
    """The motivation for when the user intends to highlight the Target resource or segment of it."""
    identifying: NamedNode
    """The motivation for when the user intends to assign an identity to the Target or identify what is being depicted or described in the Target."""
    linking: NamedNode
    """The motivation for when the user intends to link to a resource related to the Target."""
    ltrDirection: NamedNode
    """The direction of text that is read from left to right."""
    moderating: NamedNode
    """The motivation for when the user intends to assign some value or quality to the Target."""
    motivatedBy: NamedNode
    """The relationship between an Annotation and a Motivation that describes the reason for the Annotation's creation."""
    prefix: NamedNode
    """The object of the property is a snippet of content that occurs immediately before the content which is being selected by the Selector."""
    processingLanguage: NamedNode
    """The object of the property is the language that should be used for textual processing algorithms when dealing with the content of the resource, including hyphenation, line breaking, which font to use for rendering and so forth.  The value must follow the recommendations of BCP47."""
    questioning: NamedNode
    """The motivation for when the user intends to ask a question about the Target."""
    refinedBy: NamedNode
    """The relationship between a Selector and another Selector or a State and a Selector or State that should be applied to the results of the first to refine the processing of the source resource. """
    renderedVia: NamedNode
    """A system that was used by the application that created the Annotation to render the resource."""
    replying: NamedNode
    """The motivation for when the user intends to reply to a previous statement, either an Annotation or another resource."""
    rtlDirection: NamedNode
    """The direction of text that is read from right to left."""
    sourceDate: NamedNode
    """The timestamp at which the Source resource should be interpreted as being applicable to the Annotation."""
    sourceDateEnd: NamedNode
    """The end timestamp of the interval over which the Source resource should be interpreted as being applicable to the Annotation."""
    sourceDateStart: NamedNode
    """The start timestamp of the interval over which the Source resource should be interpreted as being applicable to the Annotation."""
    start: NamedNode
    """The start position in a 0-based index at which a range of content is selected from the data in the source resource."""
    styleClass: NamedNode
    """The name of the class used in the CSS description referenced from the Annotation that should be applied to the Specific Resource."""
    styledBy: NamedNode
    """A reference to a Stylesheet that should be used to apply styles to the Annotation rendering."""
    suffix: NamedNode
    """The snippet of text that occurs immediately after the text which is being selected."""
    tagging: NamedNode
    """The motivation for when the user intends to associate a tag with the Target."""
    textDirection: NamedNode
    """The direction of the text of the subject resource. There MUST only be one text direction associated with any given resource."""
    via: NamedNode
    """A object of the relationship is a resource from which the source resource was retrieved by the providing system."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class REV(PredefinedNamespace):
    """RDF Review Vocabulary"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/archive/purl.org/stuff/rev.rdf

    _nsBaseIri = "http://purl.org/stuff/rev#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Comment: NamedNode
    """A comment on a review"""
    Feedback: NamedNode
    """Feedback on the review. Expresses whether the review was useful or not"""
    Review: NamedNode
    """A review of an work"""
    commenter: NamedNode
    """The commenter on the review"""
    hasComment: NamedNode
    """Used to associate a review with a comment on the review"""
    hasFeedback: NamedNode
    """Associates a review with a feedback on the review"""
    hasReview: NamedNode
    """Associates a work with a a review"""
    maxRating: NamedNode
    """A numeric value"""
    minRating: NamedNode
    """A numeric value"""
    positiveVotes: NamedNode
    """Number of positive usefulness votes (integer)"""
    rating: NamedNode
    """A numeric value"""
    reviewer: NamedNode
    """The person that has written the review"""
    text: NamedNode
    """The text of the review"""
    title: NamedNode
    """The title of the review"""
    totalVotes: NamedNode
    """Number of usefulness votes (integer)"""
    type: NamedNode
    """The type of media of a work under review"""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class DUV(PredefinedNamespace):
    """Dataset Usage Vocabulary"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://www.w3.org/ns/duv#

    _nsBaseIri = "http://www.w3.org/ns/duv#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    RatingFeedback: NamedNode
    """Predefined criteria used to express a user opinion about a dataset or distribution using a discrete range of values."""
    Usage: NamedNode
    """A helpful description of actions that can be performed on a given dataset or distribution."""
    UsageTool: NamedNode
    """A synopsis describing the way a tool can use a dataset or distribution."""
    UserFeedback: NamedNode
    """User feedback on the dataset. Expresses whether the dataset was useful or not, for example."""
    hasDistributor: NamedNode
    """The distributor is the organization that makes the dataset available for downloading and use."""
    hasFeedback: NamedNode
    """User feedback associated with Dataset or distribution"""
    hasRating: NamedNode
    """Rating Feedback has rating opinion"""
    hasUsage: NamedNode
    """Dataset/distribution usage guidance or instructions."""
    hasUsageTool: NamedNode
    """Describes the tool that provides the Usage """
    refersTo: NamedNode
    """Dataset associated with Usage. """



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class LDP(PredefinedNamespace):
    """The W3C Linked Data Platform (LDP) Vocabulary"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/ns/ldp.ttl

    _nsBaseIri = "http://www.w3.org/ns/ldp#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Ascending: NamedNode
    """Ascending order."""
    BasicContainer: NamedNode
    """An LDPC that uses a predefined predicate to simply link to its contained resources."""
    Container: NamedNode
    """A Linked Data Platform RDF Source (LDP-RS) that also conforms to additional patterns and conventions for managing membership. Readers should refer to the specification defining this ontology for the list of behaviors associated with it."""
    Descending: NamedNode
    """Descending order."""
    DirectContainer: NamedNode
    """An LDPC that is similar to a LDP-DC but it allows an indirection with the ability to list as member a resource, such as a URI representing a real-world object, that is different from the resource that is created."""
    IndirectContainer: NamedNode
    """An LDPC that has the flexibility of choosing what form the membership triples take."""
    MemberSubject: NamedNode
    """Used to indicate default and typical behavior for ldp:insertedContentRelation, where the member-URI value in the membership triple added when a creation request is successful is the URI assigned to the newly created resource."""
    NonRDFSource: NamedNode
    """A Linked Data Platform Resource (LDPR) whose state is NOT represented as RDF."""
    Page: NamedNode
    """URI signifying that the resource is an in-sequence page resource, as defined by LDP Paging.  Typically used on Link rel='type' response headers."""
    PageSortCriterion: NamedNode
    """Element in the list of sorting criteria used by the server to assign container members to pages."""
    PreferContainment: NamedNode
    """URI identifying a LDPC's containment triples, for example to allow clients to express interest in receiving them."""
    PreferEmptyContainer: NamedNode
    """Archaic alias for ldp:PreferMinimalContainer"""
    PreferMembership: NamedNode
    """URI identifying a LDPC's membership triples, for example to allow clients to express interest in receiving them."""
    PreferMinimalContainer: NamedNode
    """URI identifying the subset of a LDPC's triples present in an empty LDPC, for example to allow clients to express interest in receiving them.  Currently this excludes containment and membership triples, but in the future other exclusions might be added.  This definition is written to automatically exclude those new classes of triples."""
    RDFSource: NamedNode
    """A Linked Data Platform Resource (LDPR) whose state is represented as RDF."""
    Resource: NamedNode
    """A HTTP-addressable resource whose lifecycle is managed by a LDP server."""
    constrainedBy: NamedNode
    """Links a resource with constraints that the server requires requests like creation and update to conform to."""
    contains: NamedNode
    """Links a container with resources created through the container."""
    hasMemberRelation: NamedNode
    """Indicates which predicate is used in membership triples, and that the membership triple pattern is < membership-constant-URI , object-of-hasMemberRelation, member-URI >."""
    inbox: NamedNode
    """Links a resource to a container where notifications for the resource can be created and discovered."""
    insertedContentRelation: NamedNode
    """Indicates which triple in a creation request should be used as the member-URI value in the membership triple added when the creation request is successful."""
    isMemberOfRelation: NamedNode
    """Indicates which predicate is used in membership triples, and that the membership triple pattern is < member-URI , object-of-isMemberOfRelation, membership-constant-URI >."""
    member: NamedNode
    """LDP servers should use this predicate as the membership predicate if there is no obvious predicate from an application vocabulary to use."""
    membershipResource: NamedNode
    """Indicates the membership-constant-URI in a membership triple.  Depending upon the membership triple pattern a container uses, as indicated by the presence of ldp:hasMemberRelation or ldp:isMemberOfRelation, the membership-constant-URI might occupy either the subject or object position in membership triples."""
    pageSequence: NamedNode
    """Link to a page sequence resource, as defined by LDP Paging.  Typically used to communicate the sorting criteria used to allocate LDPC members to pages."""
    pageSortCollation: NamedNode
    """The collation used to order the members across pages in a page sequence when comparing strings."""
    pageSortCriteria: NamedNode
    """Link to the list of sorting criteria used by the server in a representation.  Typically used on Link response headers as an extension link relation URI in the rel= parameter."""
    pageSortOrder: NamedNode
    """The ascending/descending/etc order used to order the members across pages in a page sequence."""
    pageSortPredicate: NamedNode
    """Predicate used to specify the order of the members across a page sequence's in-sequence page resources; it asserts nothing about the order of members in the representation of a single page."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class SKOSXL(PredefinedNamespace):
    """SKOS Simple Knowledge Organization System eXtension for Labels (SKOS-XL)"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://www.w3.org/TR/skos-reference/skos-xl.rdf

    _nsBaseIri = "http://www.w3.org/2008/05/skos-xl#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Label: NamedNode
    """A special class of lexical entities."""
    altLabel: NamedNode
    """The property skosxl:altLabel is used to associate an skosxl:Label with a skos:Concept. The property is analogous to skos:altLabel."""
    hiddenLabel: NamedNode
    """The property skosxl:hiddenLabel is used to associate an skosxl:Label with a skos:Concept. The property is analogous to skos:hiddenLabel."""
    labelRelation: NamedNode
    """The property skosxl:labelRelation is used for representing binary ('direct') relations between instances of the class skosxl:Label."""
    literalForm: NamedNode
    """The property skosxl:literalForm is used to give the literal form of an skosxl:Label."""
    prefLabel: NamedNode
    """The property skosxl:prefLabel is used to associate an skosxl:Label with a skos:Concept. The property is analogous to skos:prefLabel."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class AS(PredefinedNamespace):
    """Activity Streams"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/ns/activitystreams-owl

    _nsBaseIri = "http://www.w3.org/ns/activitystreams#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Accept: NamedNode
    """Actor accepts the Object"""
    Activity: NamedNode
    """An Object representing some form of Action that has been taken"""
    Add: NamedNode
    """To Add an Object or Link to Something"""
    Announce: NamedNode
    """Actor announces the object to the target"""
    Application: NamedNode
    """Represents a software application of any sort"""
    Arrive: NamedNode
    """To Arrive Somewhere (can be used, for instance, to indicate that a particular entity is currently located somewhere, e.g. a "check-in")"""
    Article: NamedNode
    """A written work. Typically several paragraphs long. For example, a blog post or a news article."""
    Audio: NamedNode
    """An audio file"""
    Collection: NamedNode
    """An ordered or unordered collection of Objects or Links"""
    CollectionPage: NamedNode
    """A subset of items from a Collection"""
    Create: NamedNode
    """To Create Something"""
    Delete: NamedNode
    """To Delete Something"""
    Dislike: NamedNode
    """The actor dislikes the object"""
    Document: NamedNode
    """Represents a digital document/file of any sort"""
    Event: NamedNode
    """An Event of any kind"""
    Flag: NamedNode
    """To flag something (e.g. flag as inappropriate, flag as spam, etc)"""
    Follow: NamedNode
    """To Express Interest in Something"""
    Group: NamedNode
    """A Group of any kind."""
    Ignore: NamedNode
    """Actor is ignoring the Object"""
    Image: NamedNode
    """An Image file"""
    IntransitiveActivity: NamedNode
    """An Activity that has no direct object"""
    Invite: NamedNode
    """To invite someone or something to something"""
    Join: NamedNode
    """To Join Something"""
    Leave: NamedNode
    """To Leave Something"""
    Like: NamedNode
    """To Like Something"""
    Link: NamedNode
    """Represents a qualified reference to another resource. Patterned after the RFC5988 Web Linking Model"""
    Listen: NamedNode
    """The actor listened to the object"""
    Mention: NamedNode
    """A specialized Link that represents an @mention"""
    Move: NamedNode
    """The actor is moving the object. The target specifies where the object is moving to. The origin specifies where the object is moving from."""
    Note: NamedNode
    """A Short note, typically less than a single paragraph. A "tweet" is an example, or a "status update"""
    Offer: NamedNode
    """To Offer something to someone or something"""
    OrderedCollection: NamedNode
    """A variation of Collection in which items are strictly ordered"""
    OrderedCollectionPage: NamedNode
    """An ordered subset of items from an OrderedCollection"""
    OrderedItems: NamedNode
    """A rdf:List variant for Objects and Links"""
    Organization: NamedNode
    """An Organization"""
    Page: NamedNode
    """A Web Page"""
    Person: NamedNode
    """A Person"""
    Place: NamedNode
    """A physical or logical location"""
    Profile: NamedNode
    """A Profile Document"""
    Question: NamedNode
    """A question of any sort."""
    Read: NamedNode
    """The actor read the object"""
    Reject: NamedNode
    """Actor rejects the Object"""
    Relationship: NamedNode
    """Represents a Social Graph relationship between two Individuals (indicated by the 'a' and 'b' properties)"""
    Remove: NamedNode
    """To Remove Something"""
    Service: NamedNode
    """A service provided by some entity"""
    TentativeAccept: NamedNode
    """Actor tentatively accepts the Object"""
    TentativeReject: NamedNode
    """Actor tentatively rejects the object"""
    Tombstone: NamedNode
    """A placeholder for a deleted object"""
    Travel: NamedNode
    """The actor is traveling to the target. The origin specifies where the actor is traveling from."""
    Undo: NamedNode
    """To Undo Something. This would typically be used to indicate that a previous Activity has been undone."""
    Update: NamedNode
    """To Update/Modify Something"""
    Video: NamedNode
    """A Video document of any kind."""
    View: NamedNode
    """The actor viewed the object"""
    accuracy: NamedNode
    """Specifies the accuracy around the point established by the longitude and latitude"""
    actor: NamedNode
    """Subproperty of as:attributedTo that identifies the primary actor"""
    altitude: NamedNode
    """The altitude of a place"""
    anyOf: NamedNode
    """Describes a possible inclusive answer or option for a question."""
    attributedTo: NamedNode
    """Identifies an entity to which an object is attributed"""
    author: NamedNode
    """Identifies the author of an object. Deprecated. Use as:attributedTo instead"""
    content: NamedNode
    """The content of the object."""
    context: NamedNode
    """Specifies the context within which an object exists or an activity was performed"""
    deleted: NamedNode
    """Specifies the date and time the object was deleted"""
    describes: NamedNode
    """On a Profile object, describes the object described by the profile"""
    duration: NamedNode
    """The duration of the object"""
    endTime: NamedNode
    """The ending time of the object"""
    formerType: NamedNode
    """On a Tombstone object, describes the former type of the deleted object"""
    height: NamedNode
    """The display height expressed as device independent pixels"""
    href: NamedNode
    """The target URI of the Link"""
    hreflang: NamedNode
    """A hint about the language of the referenced resource"""
    instrument: NamedNode
    """Indentifies an object used (or to be used) to complete an activity"""
    latitude: NamedNode
    """The latitude"""
    longitude: NamedNode
    """The longitude"""
    mediaType: NamedNode
    """The MIME Media Type"""
    oneOf: NamedNode
    """Describes a possible exclusive answer or option for a question."""
    origin: NamedNode
    """For certain activities, specifies the entity from which the action is directed."""
    published: NamedNode
    """Specifies the date and time the object was published"""
    radius: NamedNode
    """Specifies a radius around the point established by the longitude and latitude"""
    rating: NamedNode
    """A numeric rating (>= 0.0, <= 5.0) for the object"""
    rel: NamedNode
    """The RFC 5988 or HTML5 Link Relation associated with the Link"""
    relationship: NamedNode
    """On a Relationship object, describes the type of relationship"""
    startIndex: NamedNode
    """In a strictly ordered logical collection, specifies the index position of the first item in the items list"""
    startTime: NamedNode
    """The starting time of the object"""
    subject: NamedNode
    """On a Relationship object, identifies the subject. e.g. when saying "John is connected to Sally", 'subject' refers to 'John'"""
    summary: NamedNode
    """A short summary of the object"""
    totalItems: NamedNode
    """The total number of items in a logical collection"""
    units: NamedNode
    """Identifies the unit of measurement used by the radius, altitude and accuracy properties. The value can be expressed either as one of a set of predefined units or as a well-known common URI that identifies units."""
    updated: NamedNode
    """Specifies when the object was last updated"""
    url: NamedNode
    """Specifies a link to a specific representation of the Object"""
    width: NamedNode
    """Specifies the preferred display width of the content, expressed in terms of device independent pixels."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class PROF(PredefinedNamespace):
    """Profiles Vocabulary"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/TR/dx-prof/rdf/prof.ttl

    _nsBaseIri = "http://www.w3.org/ns/dx/prof/"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Profile: NamedNode
    """A specification that constrains, extends, combines, or provides guidance or explanation about the usage of other specifications.

This definition includes what are often called "application profiles", "metadata application profiles", or "metadata profiles"."""
    ResourceDescriptor: NamedNode
    """A description of a resource that defines an aspect - a particular part, feature or role - of a Profile"""
    ResourceRole: NamedNode
    """A role that an profile resource, described by a Resource Descriptor, plays"""
    hasArtifact: NamedNode
    """The URL of a downloadable file with particulars such as its format and role indicated by the Resource Descriptor"""
    hasResource: NamedNode
    """A resource which describes the nature of an artifact and the role it plays in relation to the Profile"""
    hasRole: NamedNode
    """The function of an artifact described by a Resource Descriptor, such as specification, guidance etc."""
    hasToken: NamedNode
    """The preferred identifier for the Profile, for use in circumstances where its URI cannot be used"""
    isInheritedFrom: NamedNode
    """A base specification, a Resource Descriptor from which is to be considered a Resource Descriptor for this Profile also"""
    isProfileOf: NamedNode
    """A specification for which this Profile defines constraints, extensions, or which it uses in combination with other specifications, or provides guidance or explanation about its usage"""
    isTransitiveProfileOf: NamedNode
    """The transitive closure of the prof:isProfileOf property. Relates a profile to another specification that it is a profile of, possibly via a chain of intermediate profiles that are in prof:isProfileOf relationships"""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class SIOC(PredefinedNamespace):
    """Semantically-Interlinked Online Communities"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://rdfs.org/sioc/ns#

    _nsBaseIri = "http://rdfs.org/sioc/ns#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Community: NamedNode
    """Community is a high-level concept that defines an online community and what it consists of."""
    Container: NamedNode
    """An area in which content Items are contained."""
    Forum: NamedNode
    """A discussion area on which Posts or entries are made."""
    Item: NamedNode
    """An Item is something which can be in a Container."""
    Post: NamedNode
    """An article or message that can be posted to a Forum."""
    Role: NamedNode
    """A Role is a function of a UserAccount within a scope of a particular Forum, Site, etc."""
    Site: NamedNode
    """A Site can be the location of an online community or set of communities, with UserAccounts and Usergroups creating Items in a set of Containers. It can be thought of as a web-accessible data Space."""
    Space: NamedNode
    """A Space is a place where data resides, e.g. on a website, desktop, fileshare, etc."""
    Thread: NamedNode
    """A container for a series of threaded discussion Posts or Items."""
    User: NamedNode
    """UserAccount is now preferred. This is a deprecated class for a User in an online community site."""
    UserAccount: NamedNode
    """A user account in an online community site."""
    Usergroup: NamedNode
    """A set of UserAccounts whose owners have a common purpose or interest. Can be used for access control purposes."""
    about: NamedNode
    """Specifies that this Item is about a particular resource, e.g. a Post describing a book, hotel, etc."""
    account_of: NamedNode
    """Refers to the foaf:Agent or foaf:Person who owns this sioc:UserAccount."""
    addressed_to: NamedNode
    """Refers to who (e.g. a UserAccount, e-mail address, etc.) a particular Item is addressed to."""
    administrator_of: NamedNode
    """A Site that the UserAccount is an administrator of."""
    attachment: NamedNode
    """The URI of a file attached to an Item."""
    avatar: NamedNode
    """An image or depiction used to represent this UserAccount."""
    container_of: NamedNode
    """An Item that this Container contains."""
    content: NamedNode
    """The content of the Item in plain text format."""
    content_encoded: NamedNode
    """The encoded content of the Post, contained in CDATA areas."""
    created_at: NamedNode
    """When this was created, in ISO 8601 format."""
    creator_of: NamedNode
    """A resource that the UserAccount is a creator of."""
    delivered_at: NamedNode
    """When this was delivered, in ISO 8601 format."""
    description: NamedNode
    """The content of the Post."""
    discussion_of: NamedNode
    """The Item that this discussion is about."""
    earlier_version: NamedNode
    """Links to a previous (older) revision of this Item or Post."""
    email: NamedNode
    """An electronic mail address of the UserAccount."""
    email_sha1: NamedNode
    """An electronic mail address of the UserAccount, encoded using SHA1."""
    embeds_knowledge: NamedNode
    """This links Items to embedded statements, facts and structured content."""
    feed: NamedNode
    """A feed (e.g. RSS, Atom, etc.) pertaining to this resource (e.g. for a Forum, Site, UserAccount, etc.)."""
    first_name: NamedNode
    """First (real) name of this User. Synonyms include given name or christian name."""
    follows: NamedNode
    """Indicates that one UserAccount follows another UserAccount (e.g. for microblog posts or other content item updates)."""
    function_of: NamedNode
    """A UserAccount that has this Role."""
    generator: NamedNode
    """A URI for the application used to generate this Item."""
    has_administrator: NamedNode
    """A UserAccount that is an administrator of this Site."""
    has_container: NamedNode
    """The Container to which this Item belongs."""
    has_creator: NamedNode
    """This is the UserAccount that made this resource."""
    has_discussion: NamedNode
    """A discussion that is related to this Item. The discussion can be anything, for example, a sioc:Forum or sioc:Thread, a sioct:WikiArticle or simply a foaf:Document."""
    has_function: NamedNode
    """A Role that this UserAccount has."""
    has_host: NamedNode
    """The Site that hosts this Container."""
    has_member: NamedNode
    """A UserAccount that is a member of this Usergroup."""
    has_moderator: NamedNode
    """A UserAccount that is a moderator of this Forum."""
    has_modifier: NamedNode
    """A UserAccount that modified this resource (e.g. Item, Container, Space)."""
    has_owner: NamedNode
    """A UserAccount that this resource is owned by."""
    has_parent: NamedNode
    """A Container or Forum that this Container or Forum is a child of."""
    has_part: NamedNode
    """An resource that is a part of this subject."""
    has_reply: NamedNode
    """Points to an Item or Post that is a reply or response to this Item or Post."""
    has_scope: NamedNode
    """A resource that this Role applies to."""
    has_space: NamedNode
    """A data Space which this resource is a part of."""
    has_subscriber: NamedNode
    """A UserAccount that is subscribed to this Container."""
    has_usergroup: NamedNode
    """Points to a Usergroup that has certain access to this Space."""
    host_of: NamedNode
    """A Container that is hosted on this Site."""
    id: NamedNode
    """An identifier of a SIOC concept instance. For example, a user ID. Must be unique for instances of each type of SIOC concept within the same site."""
    ip_address: NamedNode
    """The IP address used when creating this Item, UserAccount, etc. This can be associated with a creator. Some wiki articles list the IP addresses for the creator or modifiers when the usernames are absent."""
    last_activity_date: NamedNode
    """The date and time of the last activity associated with a SIOC concept instance, and expressed in ISO 8601 format. This could be due to a reply Post or Comment, a modification to an Item, etc."""
    last_item_date: NamedNode
    """The date and time of the last Post (or Item) in a Forum (or a Container), in ISO 8601 format."""
    last_name: NamedNode
    """Last (real) name of this user. Synonyms include surname or family name."""
    last_reply_date: NamedNode
    """The date and time of the last reply Post or Comment, which could be associated with a starter Item or Post or with a Thread, and expressed in ISO 8601 format."""
    later_version: NamedNode
    """Links to a later (newer) revision of this Item or Post."""
    latest_version: NamedNode
    """Links to the latest revision of this Item or Post."""
    likes: NamedNode
    """Used to indicate some form of endorsement by a UserAccount or Agent of an Item, Container, Space, UserAccount, etc."""
    link: NamedNode
    """A URI of a document which contains this SIOC object."""
    links_to: NamedNode
    """Links extracted from hyperlinks within a SIOC concept, e.g. Post or Site."""
    member_of: NamedNode
    """A Usergroup that this UserAccount is a member of."""
    mentions: NamedNode
    """Refers to a UserAccount that a particular Item mentions."""
    moderator_of: NamedNode
    """A Forum that a UserAccount is a moderator of."""
    modified_at: NamedNode
    """When this was modified, in ISO 8601 format."""
    modifier_of: NamedNode
    """A resource that this UserAccount has modified."""
    name: NamedNode
    """The name of a SIOC concept instance, e.g. a username for a UserAccount, group name for a Usergroup, etc."""
    next_by_date: NamedNode
    """Next Item or Post in a given Container sorted by date."""
    next_version: NamedNode
    """Links to the next revision of this Item or Post."""
    note: NamedNode
    """A note associated with this resource, for example, if it has been edited by a UserAccount."""
    num_authors: NamedNode
    """The number of unique authors (UserAccounts and unregistered posters) who have contributed to this Item, Thread, Post, etc."""
    num_items: NamedNode
    """The number of Posts (or Items) in a Forum (or a Container)."""
    num_replies: NamedNode
    """The number of replies that this Item, Thread, Post, etc. has. Useful for when the reply structure is absent."""
    num_threads: NamedNode
    """The number of Threads (AKA discussion topics) in a Forum."""
    num_views: NamedNode
    """The number of times this Item, Thread, UserAccount profile, etc. has been viewed."""
    owner_of: NamedNode
    """A resource owned by a particular UserAccount, for example, a weblog or image gallery."""
    parent_of: NamedNode
    """A child Container or Forum that this Container or Forum is a parent of."""
    part_of: NamedNode
    """A resource that the subject is a part of."""
    previous_by_date: NamedNode
    """Previous Item or Post in a given Container sorted by date."""
    previous_version: NamedNode
    """Links to the previous revision of this Item or Post."""
    read_at: NamedNode
    """When this was read, in ISO 8601 format."""
    reference: NamedNode
    """Links either created explicitly or extracted implicitly on the HTML level from the Post."""
    related_to: NamedNode
    """Related resources for this resource, e.g. for Posts, perhaps determined implicitly from topics or references."""
    reply_of: NamedNode
    """Links to an Item or Post which this Item or Post is a reply to."""
    respond_to: NamedNode
    """For the reply-to address set in email messages, IMs, etc. The property name was chosen to avoid confusion with has_reply/reply_of (the reply graph)."""
    scope_of: NamedNode
    """A Role that has a scope of this resource."""
    shared_by: NamedNode
    """For shared Items where there is a certain creator_of and an intermediary who shares or forwards it (e.g. as a sibling Item)."""
    sibling: NamedNode
    """An Item may have a sibling or a twin that exists in a different Container, but the siblings may differ in some small way (for example, language, category, etc.). The sibling of this Item should be self-describing (that is, it should contain all available information)."""
    space_of: NamedNode
    """A resource which belongs to this data Space."""
    subject: NamedNode
    """Keyword(s) describing subject of the Post."""
    subscriber_of: NamedNode
    """A Container that a UserAccount is subscribed to."""
    title: NamedNode
    """This is the title (subject line) of the Post. Note that for a Post within a threaded discussion that has no parents, it would detail the topic thread."""
    topic: NamedNode
    """A topic of interest, linking to the appropriate URI, e.g. in the Open Directory Project or of a SKOS category."""
    usergroup_of: NamedNode
    """A Space that the Usergroup has access to."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class VANN(PredefinedNamespace):
    """VANN: A vocabulary for annotating vocabulary descriptions"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://vocab.org/vann/vann-vocab-20100607.rdf

    _nsBaseIri = "http://purl.org/vocab/vann/"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    changes: NamedNode
    """A reference to a resource that describes changes between this version of a vocabulary and the previous."""
    example: NamedNode
    """A reference to a resource that provides an example of how this resource can be used."""
    preferredNamespacePrefix: NamedNode
    """The preferred namespace prefix to use when using terms from this vocabulary in an XML document."""
    preferredNamespaceUri: NamedNode
    """The preferred namespace URI to use when using terms from this vocabulary in an XML document."""
    termGroup: NamedNode
    """A group of related terms in a vocabulary."""
    usageNote: NamedNode
    """A reference to a resource that provides information on how this resource is to be used."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class DC11(PredefinedNamespace):
    """Dublin Core (the original fifteen-element)"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.dublincore.org/specifications/dublin-core/dcmi-terms/dublin_core_elements.nt

    _nsBaseIri = "http://purl.org/dc/elements/1.1/"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    contributor: NamedNode
    """An entity responsible for making contributions to the resource."""
    coverage: NamedNode
    """The spatial or temporal topic of the resource, spatial applicability of the resource, or jurisdiction under which the resource is relevant."""
    creator: NamedNode
    """An entity primarily responsible for making the resource."""
    date: NamedNode
    """A point or period of time associated with an event in the lifecycle of the resource."""
    description: NamedNode
    """An account of the resource."""
    format: NamedNode
    """The file format, physical medium, or dimensions of the resource."""
    identifier: NamedNode
    """An unambiguous reference to the resource within a given context."""
    language: NamedNode
    """A language of the resource."""
    publisher: NamedNode
    """An entity responsible for making the resource available."""
    relation: NamedNode
    """A related resource."""
    rights: NamedNode
    """Information about rights held in and over the resource."""
    source: NamedNode
    """A related resource from which the described resource is derived."""
    subject: NamedNode
    """The topic of the resource."""
    title: NamedNode
    """A name given to the resource."""
    type: NamedNode
    """The nature or genre of the resource."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class FOAF(PredefinedNamespace):
    """Friend of a Friend: linking people and information using the Web"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://xmlns.com/foaf/spec/index.rdf

    _nsBaseIri = "http://xmlns.com/foaf/0.1/"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Agent: NamedNode
    """An agent (eg. person, group, software or physical artifact)."""
    Document: NamedNode
    """A document."""
    Group: NamedNode
    """A class of Agents."""
    Image: NamedNode
    """An image."""
    LabelProperty: NamedNode
    """A foaf:LabelProperty is any RDF property with texual values that serve as labels."""
    OnlineAccount: NamedNode
    """An online account."""
    OnlineChatAccount: NamedNode
    """An online chat account."""
    OnlineEcommerceAccount: NamedNode
    """An online e-commerce account."""
    OnlineGamingAccount: NamedNode
    """An online gaming account."""
    Organization: NamedNode
    """An organization."""
    Person: NamedNode
    """A person."""
    PersonalProfileDocument: NamedNode
    """A personal profile RDF document."""
    Project: NamedNode
    """A project (a collective endeavour of some kind)."""
    account: NamedNode
    """Indicates an account held by this agent."""
    accountName: NamedNode
    """Indicates the name (identifier) associated with this online account."""
    accountServiceHomepage: NamedNode
    """Indicates a homepage of the service provide for this online account."""
    age: NamedNode
    """The age in years of some agent."""
    aimChatID: NamedNode
    """An AIM chat ID"""
    based_near: NamedNode
    """A location that something is based near, for some broadly human notion of near."""
    birthday: NamedNode
    """The birthday of this Agent, represented in mm-dd string form, eg. '12-31'."""
    currentProject: NamedNode
    """A current project this person works on."""
    depiction: NamedNode
    """A depiction of some thing."""
    depicts: NamedNode
    """A thing depicted in this representation."""
    dnaChecksum: NamedNode
    """A checksum for the DNA of some thing. Joke."""
    familyName: NamedNode
    """The family name of some person."""
    family_name: NamedNode
    """The family name of some person."""
    firstName: NamedNode
    """The first name of a person."""
    focus: NamedNode
    """The underlying or 'focal' entity associated with some SKOS-described concept."""
    fundedBy: NamedNode
    """An organization funding a project or person."""
    geekcode: NamedNode
    """A textual geekcode for this person, see http://www.geekcode.com/geek.html"""
    gender: NamedNode
    """The gender of this Agent (typically but not necessarily 'male' or 'female')."""
    givenName: NamedNode
    """The given name of some person."""
    givenname: NamedNode
    """The given name of some person."""
    holdsAccount: NamedNode
    """Indicates an account held by this agent."""
    homepage: NamedNode
    """A homepage for some thing."""
    icqChatID: NamedNode
    """An ICQ chat ID"""
    img: NamedNode
    """An image that can be used to represent some thing (ie. those depictions which are particularly representative of something, eg. one's photo on a homepage)."""
    interest: NamedNode
    """A page about a topic of interest to this person."""
    isPrimaryTopicOf: NamedNode
    """A document that this thing is the primary topic of."""
    jabberID: NamedNode
    """A jabber ID for something."""
    knows: NamedNode
    """A person known by this person (indicating some level of reciprocated interaction between the parties)."""
    lastName: NamedNode
    """The last name of a person."""
    logo: NamedNode
    """A logo representing some thing."""
    made: NamedNode
    """Something that was made by this agent."""
    maker: NamedNode
    """An agent that 
made this thing."""
    mbox: NamedNode
    """A 
personal mailbox, ie. an Internet mailbox associated with exactly one owner, the first owner of this mailbox. This is a 'static inverse functional property', in that  there is (across time and change) at most one individual that ever has any particular value for foaf:mbox."""
    mbox_sha1sum: NamedNode
    """The sha1sum of the URI of an Internet mailbox associated with exactly one owner, the  first owner of the mailbox."""
    member: NamedNode
    """Indicates a member of a Group"""
    membershipClass: NamedNode
    """Indicates the class of individuals that are a member of a Group"""
    msnChatID: NamedNode
    """An MSN chat ID"""
    myersBriggs: NamedNode
    """A Myers Briggs (MBTI) personality classification."""
    name: NamedNode
    """A name for some thing."""
    nick: NamedNode
    """A short informal nickname characterising an agent (includes login identifiers, IRC and other chat nicknames)."""
    openid: NamedNode
    """An OpenID for an Agent."""
    page: NamedNode
    """A page or document about this thing."""
    pastProject: NamedNode
    """A project this person has previously worked on."""
    phone: NamedNode
    """A phone,  specified using fully qualified tel: URI scheme (refs: http://www.w3.org/Addressing/schemes.html#tel)."""
    plan: NamedNode
    """A .plan comment, in the tradition of finger and '.plan' files."""
    primaryTopic: NamedNode
    """The primary topic of some page or document."""
    publications: NamedNode
    """A link to the publications of this person."""
    schoolHomepage: NamedNode
    """A homepage of a school attended by the person."""
    sha1: NamedNode
    """A sha1sum hash, in hex."""
    skypeID: NamedNode
    """A Skype ID"""
    status: NamedNode
    """A string expressing what the user is happy for the general public (normally) to know about their current activity."""
    surname: NamedNode
    """The surname of some person."""
    theme: NamedNode
    """A theme."""
    thumbnail: NamedNode
    """A derived thumbnail image."""
    tipjar: NamedNode
    """A tipjar document for this agent, describing means for payment and reward."""
    title: NamedNode
    """Title (Mr, Mrs, Ms, Dr. etc)"""
    topic: NamedNode
    """A topic of some page or document."""
    topic_interest: NamedNode
    """A thing of interest to this person."""
    weblog: NamedNode
    """A weblog of some thing (whether person, group, company etc.)."""
    workInfoHomepage: NamedNode
    """A work info homepage of some person; a page about their work for some organization."""
    workplaceHomepage: NamedNode
    """A workplace homepage of some person; the homepage of an organization they work for."""
    yahooChatID: NamedNode
    """A Yahoo chat ID"""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class OWL(PredefinedNamespace):
    """The OWL 2 Schema vocabulary (OWL 2)"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://www.w3.org/2002/07/owl#

    _nsBaseIri = "http://www.w3.org/2002/07/owl#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    AllDifferent: NamedNode
    """The class of collections of pairwise different individuals."""
    AllDisjointClasses: NamedNode
    """The class of collections of pairwise disjoint classes."""
    AllDisjointProperties: NamedNode
    """The class of collections of pairwise disjoint properties."""
    Annotation: NamedNode
    """The class of annotated annotations for which the RDF serialization consists of an annotated subject, predicate and object."""
    AnnotationProperty: NamedNode
    """The class of annotation properties."""
    AsymmetricProperty: NamedNode
    """The class of asymmetric properties."""
    Axiom: NamedNode
    """The class of annotated axioms for which the RDF serialization consists of an annotated subject, predicate and object."""
    Class: NamedNode
    """The class of OWL classes."""
    DataRange: NamedNode
    """The class of OWL data ranges, which are special kinds of datatypes. Note: The use of the IRI owl:DataRange has been deprecated as of OWL 2. The IRI rdfs:Datatype SHOULD be used instead."""
    DatatypeProperty: NamedNode
    """The class of data properties."""
    DeprecatedClass: NamedNode
    """The class of deprecated classes."""
    DeprecatedProperty: NamedNode
    """The class of deprecated properties."""
    FunctionalProperty: NamedNode
    """The class of functional properties."""
    InverseFunctionalProperty: NamedNode
    """The class of inverse-functional properties."""
    IrreflexiveProperty: NamedNode
    """The class of irreflexive properties."""
    NamedIndividual: NamedNode
    """The class of named individuals."""
    NegativePropertyAssertion: NamedNode
    """The class of negative property assertions."""
    Nothing: NamedNode
    """This is the empty class."""
    ObjectProperty: NamedNode
    """The class of object properties."""
    Ontology: NamedNode
    """The class of ontologies."""
    OntologyProperty: NamedNode
    """The class of ontology properties."""
    ReflexiveProperty: NamedNode
    """The class of reflexive properties."""
    Restriction: NamedNode
    """The class of property restrictions."""
    SymmetricProperty: NamedNode
    """The class of symmetric properties."""
    Thing: NamedNode
    """The class of OWL individuals."""
    TransitiveProperty: NamedNode
    """The class of transitive properties."""
    allValuesFrom: NamedNode
    """The property that determines the class that a universal property restriction refers to."""
    annotatedProperty: NamedNode
    """The property that determines the predicate of an annotated axiom or annotated annotation."""
    annotatedSource: NamedNode
    """The property that determines the subject of an annotated axiom or annotated annotation."""
    annotatedTarget: NamedNode
    """The property that determines the object of an annotated axiom or annotated annotation."""
    assertionProperty: NamedNode
    """The property that determines the predicate of a negative property assertion."""
    backwardCompatibleWith: NamedNode
    """The annotation property that indicates that a given ontology is backward compatible with another ontology."""
    bottomDataProperty: NamedNode
    """The data property that does not relate any individual to any data value."""
    bottomObjectProperty: NamedNode
    """The object property that does not relate any two individuals."""
    cardinality: NamedNode
    """The property that determines the cardinality of an exact cardinality restriction."""
    complementOf: NamedNode
    """The property that determines that a given class is the complement of another class."""
    datatypeComplementOf: NamedNode
    """The property that determines that a given data range is the complement of another data range with respect to the data domain."""
    deprecated: NamedNode
    """The annotation property that indicates that a given entity has been deprecated."""
    differentFrom: NamedNode
    """The property that determines that two given individuals are different."""
    disjointUnionOf: NamedNode
    """The property that determines that a given class is equivalent to the disjoint union of a collection of other classes."""
    disjointWith: NamedNode
    """The property that determines that two given classes are disjoint."""
    distinctMembers: NamedNode
    """The property that determines the collection of pairwise different individuals in a owl:AllDifferent axiom."""
    equivalentClass: NamedNode
    """The property that determines that two given classes are equivalent, and that is used to specify datatype definitions."""
    equivalentProperty: NamedNode
    """The property that determines that two given properties are equivalent."""
    hasKey: NamedNode
    """The property that determines the collection of properties that jointly build a key."""
    hasSelf: NamedNode
    """The property that determines the property that a self restriction refers to."""
    hasValue: NamedNode
    """The property that determines the individual that a has-value restriction refers to."""
    imports: NamedNode
    """The property that is used for importing other ontologies into a given ontology."""
    incompatibleWith: NamedNode
    """The annotation property that indicates that a given ontology is incompatible with another ontology."""
    intersectionOf: NamedNode
    """The property that determines the collection of classes or data ranges that build an intersection."""
    inverseOf: NamedNode
    """The property that determines that two given properties are inverse."""
    maxCardinality: NamedNode
    """The property that determines the cardinality of a maximum cardinality restriction."""
    maxQualifiedCardinality: NamedNode
    """The property that determines the cardinality of a maximum qualified cardinality restriction."""
    members: NamedNode
    """The property that determines the collection of members in either a owl:AllDifferent, owl:AllDisjointClasses or owl:AllDisjointProperties axiom."""
    minCardinality: NamedNode
    """The property that determines the cardinality of a minimum cardinality restriction."""
    minQualifiedCardinality: NamedNode
    """The property that determines the cardinality of a minimum qualified cardinality restriction."""
    onClass: NamedNode
    """The property that determines the class that a qualified object cardinality restriction refers to."""
    onDataRange: NamedNode
    """The property that determines the data range that a qualified data cardinality restriction refers to."""
    onDatatype: NamedNode
    """The property that determines the datatype that a datatype restriction refers to."""
    onProperties: NamedNode
    """The property that determines the n-tuple of properties that a property restriction on an n-ary data range refers to."""
    onProperty: NamedNode
    """The property that determines the property that a property restriction refers to."""
    oneOf: NamedNode
    """The property that determines the collection of individuals or data values that build an enumeration."""
    priorVersion: NamedNode
    """The annotation property that indicates the predecessor ontology of a given ontology."""
    propertyChainAxiom: NamedNode
    """The property that determines the n-tuple of properties that build a sub property chain of a given property."""
    propertyDisjointWith: NamedNode
    """The property that determines that two given properties are disjoint."""
    qualifiedCardinality: NamedNode
    """The property that determines the cardinality of an exact qualified cardinality restriction."""
    sameAs: NamedNode
    """The property that determines that two given individuals are equal."""
    someValuesFrom: NamedNode
    """The property that determines the class that an existential property restriction refers to."""
    sourceIndividual: NamedNode
    """The property that determines the subject of a negative property assertion."""
    targetIndividual: NamedNode
    """The property that determines the object of a negative object property assertion."""
    targetValue: NamedNode
    """The property that determines the value of a negative data property assertion."""
    topDataProperty: NamedNode
    """The data property that relates every individual to every data value."""
    topObjectProperty: NamedNode
    """The object property that relates every two individuals."""
    unionOf: NamedNode
    """The property that determines the collection of classes or data ranges that build a union."""
    versionIRI: NamedNode
    """The property that identifies the version IRI of an ontology."""
    versionInfo: NamedNode
    """The annotation property that provides version information for an ontology or another OWL construct."""
    withRestrictions: NamedNode
    """The property that determines the collection of facet-value pairs that define a datatype restriction."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class XSD(PredefinedNamespace):
    """W3C XML Schema Definition Language (XSD) 1.1 Part 2: Datatypes"""

    _nsBaseIri = "http://www.w3.org/2001/XMLSchema#"
    _issueWarning = False

    # This module was written by hand

    anyURI: NamedNode
    base64Binary: NamedNode
    boolean: NamedNode
    byte: NamedNode
    date: NamedNode
    dateTime: NamedNode
    dateTimeStamp: NamedNode
    dayTimeDuration: NamedNode
    decimal: NamedNode
    double: NamedNode
    duration: NamedNode
    ENTITIES: NamedNode
    ENTITY: NamedNode
    float: NamedNode
    gDay: NamedNode
    gMonth: NamedNode
    gMonthDay: NamedNode
    gYear: NamedNode
    gYearMonth: NamedNode
    hexBinary: NamedNode
    ID: NamedNode
    IDREF: NamedNode
    IDREFS: NamedNode
    int: NamedNode
    integer: NamedNode
    language: NamedNode
    long: NamedNode
    Name: NamedNode
    NCName: NamedNode
    negativeInteger: NamedNode
    NMTOKEN: NamedNode
    NMTOKENS: NamedNode
    nonNegativeInteger: NamedNode
    nonPositiveInteger: NamedNode
    normalizedString: NamedNode
    NOTATION: NamedNode
    positiveInteger: NamedNode
    QName: NamedNode
    short: NamedNode
    string: NamedNode
    time: NamedNode
    token: NamedNode
    unsignedByte: NamedNode
    unsignedInt: NamedNode
    unsignedLong: NamedNode
    unsignedShort: NamedNode
    yearMonthDuration: NamedNode
